@charset "UTF-8";
@import "https://fonts.googleapis.com/css?family=Open+Sans:400,600";
@font-face {
	font-family: 'wcmp';
	src: url("../fonts/wcmp-font.eot?lyp4c7");
	src: url("../fonts/wcmp-font.eot?lyp4c7#iefix") format("embedded-opentype"), url("../fonts/wcmp-font.ttf?lyp4c7") format("truetype"), url("../fonts/wcmp-font.woff?lyp4c7") format("woff");
	font-weight: normal;
	font-style: normal;
}
/*....................... shipping page .....................*/
/*********************** Ledger Report *************************/
/*# sourceMappingURL=vendor_dashboard.css.map */
i.wcmp-font {
	font-family: 'wcmp' !important;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;
	vertical-align: middle;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.ico-cancel-status-icon {
	&:before {
		content: "\e94f";
	}
}
.ico-completed-status-icon {
	&:before {
		content: "\e950";
	}
}
.ico-customer-details-icon {
	&:before {
		content: "\e951";
	}
}
.ico-download2-icon {
	&:before {
		content: "\e952";
	}
}
.ico-email-invoice-icon {
	&:before {
		content: "\e953";
	}
}
.ico-failed-status-icon {
	&:before {
		content: "\e954";
	}
}
.ico-order-commission {
	&:before {
		content: "\e955";
	}
}
.ico-order-detailsnew-icon {
	&:before {
		content: "\e956";
	}
}
.ico-pendingpayment-status-icon {
	&:before {
		content: "\e957";
	}
}
.ico-processing-status-icon {
	&:before {
		content: "\e958";
	}
}
.ico-refunded-status-icon {
	&:before {
		content: "\e959";
	}
}
.ico-resend-notification-icon {
	&:before {
		content: "\e95a";
	}
}
.ico-shippingnew2-icon {
	&:before {
		content: "\e95b";
	}
}
.ico-duplicate-icon {
	&:before {
		content: "\e94e";
	}
}
.ico-back-arrow {
	&:before {
		content: "\e94d";
	}
}
.ico-search-icon {
	&:before {
		content: "\e94c";
	}
}
.ico-export {
	&:before {
		content: "\e91b";
	}
}
.ico-import {
	&:before {
		content: "\e921";
	}
}
.ico-message {
	&:before {
		content: "\e92b";
	}
}
.ico-notification {
	&:before {
		content: "\e930";
	}
}
.ico-quote {
	&:before {
		content: "\e937";
	}
}
.ico-rental-calender {
	&:before {
		content: "\e940";
	}
}
.ico-resources {
	&:before {
		content: "\e941";
	}
}
.ico-subscriptions {
	&:before {
		content: "\e94a";
	}
}
.ico-add-booking {
	&:before {
		content: "\e94b";
	}
}
.ico-uncheckbox-icon {
	&:before {
		content: "\e915";
	}
}
.ico-check-box-icon {
	&:before {
		content: "\e90b";
	}
}
.ico-approve-icon {
	&:before {
		content: "\e943";
	}
}
.ico-delete-icon {
	&:before {
		content: "\e944";
	}
}
.ico-expire-icon {
	&:before {
		content: "\e945";
	}
}
.ico-reject-icon {
	&:before {
		content: "\e946";
	}
}
.ico-rental-icon {
	&:before {
		content: "\e947";
	}
}
.ico-reply-icon {
	&:before {
		content: "\e948";
	}
}
.ico-rupee-icon {
	&:before {
		content: "\e949";
	}
}
.ico-addcoupon-icon {
	&:before {
		content: "\e900";
	}
}
.ico-add-icon {
	&:before {
		content: "\e901";
	}
}
.ico-add-product-icon {
	&:before {
		content: "\e902";
	}
}
.ico-all-bookings-icon {
	&:before {
		content: "\e903";
	}
}
.ico-announcement-icon {
	&:before {
		content: "\e904";
	}
}
.ico-avarage-order-value-icon {
	&:before {
		content: "\e905";
	}
}
.ico-billing-icon {
	&:before {
		content: "\e906";
	}
}
.ico-booking-icon {
	&:before {
		content: "\e907";
	}
}
.ico-calendar-icon {
	&:before {
		content: "\e908";
	}
}
.ico-cart-icon {
	&:before {
		content: "\e909";
	}
}
.ico-catalog-icon {
	&:before {
		content: "\e90a";
	}
}
.ico-coupons-icon {
	&:before {
		content: "\e90c";
	}
}
.ico-dashboard-icon {
	&:before {
		content: "\e90d";
	}
}
.ico-downarrow-2-icon {
	&:before {
		content: "\e90e";
	}
}
.ico-down-arrow-icon {
	&:before {
		content: "\e90f";
	}
}
.ico-download-icon {
	&:before {
		content: "\e910";
	}
}
.ico-earning-icon {
	&:before {
		content: "\e911";
	}
}
.ico-edit-pencil-icon {
	&:before {
		content: "\e912";
	}
}
.ico-export-icon {
	&:before {
		content: "\e913";
	}
}
.ico-eye-icon {
	&:before {
		content: "\e914";
	}
}
.ico-history-icon {
	&:before {
		content: "\e916";
	}
}
.ico-image-icon {
	&:before {
		content: "\e917";
	}
}
.ico-import-icon {
	&:before {
		content: "\e918";
	}
}
.ico-knowledgebase-icon {
	&:before {
		content: "\e919";
	}
}
.ico-left-arrow-icon {
	&:before {
		content: "\e91a";
	}
}
.ico-logout-icon {
	&:before {
		content: "\e91c";
	}
}
.ico-minus-icon {
	&:before {
		content: "\e91d";
	}
}
.ico-my-shop-icon {
	&:before {
		content: "\e91e";
	}
}
.ico-order-details-icon {
	&:before {
		content: "\e91f";
	}
}
.ico-orders-icon {
	&:before {
		content: "\e920";
	}
}
.ico-payments-icon {
	&:before {
		content: "\e922";
	}
}
.ico-pdf-icon {
	&:before {
		content: "\e923";
	}
}
.ico-plus-icon {
	&:before {
		content: "\e924";
	}
}
.ico-policies-icon {
	&:before {
		content: "\e925";
	}
}
.ico-price2-icon {
	&:before {
		content: "\e926";
	}
}
.ico-price-icon {
	&:before {
		content: "\e927";
	}
}
.ico-product-icon {
	&:before {
		content: "\e928";
	}
}
.ico-product-manager-icon {
	&:before {
		content: "\e929";
	}
}
.ico-questionmark-icon {
	&:before {
		content: "\e92a";
	}
}
.ico-report-icon {
	&:before {
		content: "\e92c";
	}
}
.ico-reports-icon {
	&:before {
		content: "\e92d";
	}
}
.ico-revenue-icon {
	&:before {
		content: "\e92e";
	}
}
.ico-right-arrow-icon {
	&:before {
		content: "\e92f";
	}
}
.ico-shipping-action-icon {
	&:before {
		content: "\e931";
	}
}
.ico-shipping-icon {
	&:before {
		content: "\e932";
	}
}
.ico-shippingnew-icon {
	&:before {
		content: "\e933";
	}
}
.ico-storefront-icon {
	&:before {
		content: "\e934";
	}
}
.ico-store-settings-icon {
	&:before {
		content: "\e935";
	}
}
.ico-tools-icon {
	&:before {
		content: "\e936";
	}
}
.ico-uparrow-2-icon {
	&:before {
		content: "\e938";
	}
}
.ico-up-arrow-icon {
	&:before {
		content: "\e939";
	}
}
.ico-upload-image-icon {
	&:before {
		content: "\e93a";
	}
}
.ico-user-icon {
	&:before {
		content: "\e93b";
	}
}
.ico-vendor-stuff-icon {
	&:before {
		content: "\e93c";
	}
}
.ico-verified-icon {
	&:before {
		content: "\e93d";
	}
}
.ico-visit-icon {
	&:before {
		content: "\e93e";
	}
}
.ico-welcome-icon {
	&:before {
		content: "\e93f";
	}
}
.ico-wp-backend-icon {
	&:before {
		content: "\e942";
	}
}
body {
	font-family: "Open Sans", sans-serif;
	color: #626c6f;
	font-size: 14px;
	line-height: 1.3;
	overflow-x: hidden;
	textarea.form-control {
		height: 100px;
		overflow-x: hidden;
	}
	.mCSB_scrollTools {
		margin: 0 !important;
		width: 8px;
		.mCSB_draggerRail {
			background: #444e50 !important;
			width: 100%;
			border-radius: 0;
		}
		.mCSB_dragger_bar {
			background: #0d1114 !important;
			width: 100% !important;
			border-radius: 10px !important;
			margin: 0 !important;
			width: 100% !important;
		}
	}
	.select2-container {
		width: 100% !important;
		min-height: 34px !important;
		.select2-selection.select2-selection--multiple {
			height: auto;
			min-height: 34px;
			width: 100%;
			border: 1px solid #c5c5c5;
			max-height: 76px;
			overflow: auto;
			border-radius: 4px;
			.select2-selection__rendered {
				padding: 3px 5px 0;
				.select2-selection__choice {
					padding: 1px 7px;
					font-size: 11px;
					margin: 5px 8px 0 0;
				}
			}
		}
		.select2-search--inline {
			margin-top: 4px;
			line-height: 18px;
			.select2-search__field {
				margin: 0 !important;
				font-size: 14px !important;
				line-height: 18px;
				padding: 0px;
			}
		}
		.select2-selection--single {
			height: 34px;
			border: 1px solid #c5c5c5;
			.select2-selection__rendered {
				line-height: 33px !important;
			}
		}
	}
	.ui-accordion {
		border-bottom: 1px solid #d8d8d8;
		font-size: 14px;
		.ui-accordion-header {
			background: #ececec;
			color: #555555;
			border-radius: 0;
			box-shadow: none !important;
			border: 1px solid #d8d8d8;
			border-width: 1px 1px 0 1px;
			margin: 0;
			padding-top: 12px;
			padding-bottom: 12px;
			font-size: 16px;
			&:last-of-type {
				border-bottom-width: 1px;
			}
			&:focus {
				outline: none;
			}
		}
		.ui-accordion-header.ui-accordion-header-active {
			background: #d8d8d8;
			color: #555555;
			&:hover {
				background: #d8d8d8;
			}
		}
		.ui-accordion-header.ui-state-hover {
			background: #e5e5e5;
		}
		.ui-accordion-content {
			border-radius: 0;
			border-color: #d8d8d8;
			border-bottom: none;
			&:last-of-type {
				border: 1px solid #d8d8d8;
			}
		}
	}
	.ui-widget {
		input {
			font-size: 14px;
		}
		select {
			font-size: 14px;
		}
		textarea {
			font-size: 14px;
		}
		button {
			font-size: 14px;
		}
		font-size: 14px;
		font-family: "Open Sans", sans-serif;
		color: #626c6f;
	}
	.mce-btn {
		button {
			color: #626c6f;
		}
	}
	.mce-ico {
		color: #626c6f;
	}
	table.dataTable.dtr-inline.collapsed {
		>tbody {
			>tr[role="row"] {
				>td {
					&:first-child {
						&:before {
							line-height: 15px;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							line-height: 15px;
						}
					}
				}
			}
		}
	}
	.media-frame {
		select {
			line-height: 21px;
		}
	}
	.wp-admin {
		.media-frame {
			select {
				line-height: 21px;
			}
		}
	}
	.woocommerce-exporter-wrapper {
		.button {
			box-shadow: none !important;
			text-shadow: none !important;
			line-height: 20px !important;
			font-size: 14px !important;
			padding: 3px 8px !important;
			border: 1px solid !important;
		}
	}
	.woocommerce-importer-wrapper {
		.button {
			box-shadow: none !important;
			text-shadow: none !important;
			line-height: 20px !important;
			font-size: 14px !important;
			padding: 3px 8px !important;
			border: 1px solid !important;
		}
	}
	.woocommerce-progress-form-wrapper {
		.button {
			box-shadow: none !important;
			text-shadow: none !important;
			line-height: 20px !important;
			font-size: 14px !important;
			padding: 3px 8px !important;
			border: 1px solid !important;
		}
		margin-top: 10px;
	}
	.woocommerce.wrap {
		margin: 0;
	}
	.wc_bookings_calendar_form {
		.tablenav {
			border: none;
			box-shadow: none;
			margin: 0 0 25px;
			display: inline-block;
			width: 100%;
			border-bottom: solid 1px #d3dbe2;
			padding-bottom: 20px;
			.date_selector {
				margin-left: 5px;
				display: block;
				float: left;
				a {
					display: block;
					text-indent: -9999px;
					position: relative;
					height: 1em;
					width: 1em;
					font-size: 1.3em;
					padding: .6em;
					&:before {
						font: normal normal normal 25px/1 LineAwesome;
						speak: none;
						font-weight: 400;
						font-variant: normal;
						text-transform: none;
						line-height: 1;
						-webkit-font-smoothing: antialiased;
						margin: 0;
						text-indent: 0;
						position: absolute;
						top: 0;
						left: 0;
						width: 100%;
						height: 100%;
						text-align: center;
					}
				}
				a.prev {
					padding: 0;
					margin: 6px 6px 0;
					width: 29px;
					height: 29px;
					position: relative;
					float: left;
					&:before {
						content: "←";
						font-size: 30px;
					}
				}
				a.next {
					padding: 0;
					margin: 6px 6px 0;
					width: 29px;
					height: 29px;
					position: relative;
					float: right;
					&:before {
						content: "→";
						font-size: 30px;
					}
				}
				div {
					padding: 5px 0;
					float: left;
					&:first-of-type {
						select {
							margin-right: 5px;
						}
					}
				}
				select {
					vertical-align: middle;
					width: 6em;
				}
			}
			.views {
				float: right;
				padding: 0;
				border-left: 1px solid #ddd;
				a {
					padding: 11px 20px;
					display: block;
					text-decoration: none;
					i {
						font-size: 19px;
						margin-right: 7px;
					}
				}
			}
			.filters {
				float: left;
				line-height: 30px;
				padding: 5px 15px 5px 5px;
				border-right: 1px solid #ddd;
			}
		}
		.calendar_days {
			overflow: auto;
			position: relative;
			height: 1440px;
			overflow: hidden;
			overflow-x: auto;
			border: 1px solid #ddd;
			background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAA8CAYAAACn8dD6AAAAIElEQVQYGWO4e/fuf4afP3/+Z2IAgsFCfP36lWHQuQoAvaoOvF/jxHkAAAAASUVORK5CYII=);
			background-repeat: repeat;
			background-position: 0 0;
			.hours {
				list-style: none;
				padding: 0;
				position: absolute;
				top: 0;
				left: 0;
				margin: -0.5em 0 0 0;
				li {
					height: 60px;
					vertical-align: top;
					padding: 0;
					margin: 0;
					label {
						float: left;
						background: #f9f9f9;
						padding: 0 8px;
					}
				}
			}
			.bookings {
				margin: 0 0 0 100px;
				padding: 0;
				height: 100%;
				white-space: nowrap;
				position: relative;
				li {
					position: absolute;
					width: 98px;
					background: #000;
					border-radius: 2px;
					margin: 0;
					overflow: hidden;
					color: #fff;
					a {
						display: block;
						padding: 2px 4px;
						height: 100%;
						width: 100%;
						position: relative;
						color: #fff;
						text-decoration: none;
					}
				}
			}
		}
		.wc_bookings_calendar {
			.calendar-diff-month {
				background: #efefef;
			}
			td {
				color: #bbb;
				text-align: right;
				padding: 8px 8px 0 0;
				font-size: 20px;
				border-right: 1px solid #ddd;
				border-bottom: 1px solid #ddd;
				height: 120px;
				.bookings {
					overflow: auto;
					height: 100px;
					width: 100%;
					text-align: left;
					font-size: 15px;
					ul {
						padding: 0;
						margin: 0;
						li {
							padding: 0;
							margin: 0 0 4px 0;
							list-style: none;
							a {
								border-left: 4px solid #eee;
								padding: 3px 3px 3px 8px;
								display: block;
								ul {
									padding: 0;
									margin: 0;
									li {
										list-style: none;
										font-size: .75em;
										padding: 0;
										margin: 0;
										border: 0;
									}
								}
								&:hover {
									border-left-color: #ccc;
									background: #fafafa;
								}
							}
						}
					}
				}
			}
		}
	}
	.select2-container--default {
		.select2-search--inline {
			.select2-search__field[placeholder] {
				&:not([placeholder=""]) {
					width: 100% !important;
				}
			}
		}
	}
}
h1 {
	color: #333b3d;
	margin: 0 0 15px;
	font-size: 30px;
	font-weight: 400;
	line-height: 38px;
}
h2 {
	color: #202627;
	font-size: 18px;
	margin: 0;
	line-height: 1.3;
}
h3 {
	color: #252525;
	font-size: 14px;
	line-height: 22px;
	margin: 0 0 15px;
}
h4 {
	color: #525252;
	font-size: 15px;
	margin: 0 0 15px;
}
a {
	cursor: pointer;
	color: #3f85b9;
	&:hover {
		text-decoration: none;
		box-shadow: none;
		outline: none;
		color: #333b3d;
	}
	&:focus {
		text-decoration: none;
		box-shadow: none;
		outline: none;
		color: #333b3d;
	}
	&:active {
		text-decoration: none;
		box-shadow: none;
		outline: none;
		color: #333b3d;
	}
}
button {
	&:focus {
		outline: none;
	}
	padding: 3px 5px 4px;
	box-shadow: none;
	line-height: 20px;
}
img {
	max-width: 100%;
	height: auto;
}
label {
	font-weight: normal;
	color: inherit;
	.tool_tip {
		top: 0;
		right: 0;
		&:after {
			top: 0;
			right: 0;
			transform: none;
		}
	}
}
.label {
	font-weight: normal;
	color: inherit;
	font-size: inherit;
}
select {
	&:not([multiple]) {
		-webkit-appearance: none;
		-moz-appearance: none;
		-ms-appearance: none;
		-o-appearance: none;
		appearance: none;
		padding-right: 27px !important;
		background-image: url("../../images/down-arrow.png");
		background-repeat: no-repeat;
		background-position: right 13px top 50%;
		background-color: #fff;
		padding: 3px 5px 4px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #d3dbe2;
		border-radius: 4px;
		height: 34px;
		&::-ms-expand {
			display: none;
		}
	}
}
select.form-control {
	&:not([multiple]) {
		-webkit-appearance: none;
		-moz-appearance: none;
		-ms-appearance: none;
		-o-appearance: none;
		appearance: none;
		padding-right: 27px !important;
		background-image: url("../../images/down-arrow.png");
		background-repeat: no-repeat;
		background-position: right 13px top 50%;
		background-color: #fff;
		padding: 3px 5px 4px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #d3dbe2;
		border-radius: 4px;
		height: 34px;
		&::-ms-expand {
			display: none;
		}
	}
}
select[multiple] {
	height: 100px;
	border-color: #d3dbe2;
}
.select-wrap {
	position: relative;
	display: inline-block;
	&:after {
		position: absolute;
		content: '\e90c';
		right: 10px;
		top: 50%;
		transform: translateY(-50%);
		font-family: 'wcmp' !important;
		color: #737377;
		font-size: 13px;
	}
}
.inline-input {
	width: auto;
	display: inline-block;
	vertical-align: middle;
}
.verticalAlign {
	display: inline-block;
	vertical-align: middle;
}
.current-endpoint-title-wrapper {
	.current-endpoint {
		i {
			display: inline-block;
			vertical-align: middle;
			margin-right: 10px;
			font-size: 21px;
		}
		span {
			display: inline-block;
			vertical-align: middle;
		}
		display: inline-block;
		margin-top: 5px;
		color: #333b3d;
		font-size: 18px;
	}
	height: 65px;
	background-color: #d3dbe2;
	padding: 15px 30px;
	position: fixed;
	width: 100%;
	left: 284px;
	top: 64px;
	z-index: 3;
	transition: all 0.4s;
	+ {
		.content-padding {
			padding-top: 94px;
		}
	}
}
.wcmp_vendor_products_cust_qna {
	.customer-questions-panel {
		article {
			.media {
				.media-body {
					.qna-date {
						i {
							display: inline-block;
							vertical-align: middle;
							font-size: 16px;
						}
						span {
							display: inline-block;
							vertical-align: middle;
						}
						font-size: 13px;
						display: block;
					}
					.qna-question {
						color: #4e4e4e;
						font-size: 14px;
						position: relative;
						padding-left: 20px;
						margin-bottom: 3px;
						&::before {
							content: 'Q.';
							color: #000;
							position: absolute;
							left: 0;
						}
						span {
							color: #000000;
						}
						+ {
							textarea {
								margin-top: 7px;
							}
						}
					}
					h4 {
						line-height: 18px;
					}
					a {
						margin-top: 9px;
						font-size: 15px;
						line-height: 100%;
						&:hover {
							color: #000;
						}
					}
				}
			}
			padding: 20px !important;
			overflow: hidden;
			border-bottom: solid 1px #d3dbe2;
			&:last-of-type {
				margin-bottom: 0;
			}
		}
		#customer_questions {
			td {
				padding: 0;
			}
		}
	}
}
form.stat-date-range {
	.panel-heading {
		h3 {
			display: inline-block;
			vertical-align: middle;
		}
		.form-group {
			display: inline-block;
			vertical-align: middle;
			margin-left: 10px;
		}
	}
}
ul {
	list-style: none;
	padding: 0;
	margin: 0;
}
.default-content-css {
	ul {
		display: block;
		list-style-type: disc;
		-webkit-margin-before: 1em;
		-webkit-margin-after: 1em;
		-webkit-margin-start: 0px;
		-webkit-margin-end: 0px;
		-webkit-padding-start: 40px;
		li {
			display: list-item;
			text-align: -webkit-match-parent;
		}
	}
	h1 {
		margin: 0.5em 0;
	}
	h2 {
		margin: 0.5em 0;
	}
	h3 {
		margin: 0.5em 0;
	}
}
.zero-radius {
	border-radius: 0;
}
.btm-margin-0 {
	margin-bottom: 0;
}
.cover-page-wrap {
	margin: 0 -30px;
}
.white-bkg {
	background-color: #fff;
}
.light-gray-bkg {
	background: #f7f8fa;
}
.gray-bkg {
	background: #edf0f1;
}
.content-padding {
	padding: 30px;
	&:not(.dashboard) {
		.dataTables_wrapper.dt-bootstrap {
			.dataTables_paginate {
				text-align: right;
				ul {
					margin: 0;
				}
				li {
					margin: 0;
					a {
						padding: 5px 20px;
						font-size: 16px;
						margin: 0;
					}
				}
				li.previous {
					a {
						border: 1px solid #c5c5c5;
					}
				}
				li.next {
					a {
						border: 1px solid #c5c5c5;
					}
				}
			}
		}
	}
}
.m-0 {
	margin: 0 !important;
}
.p-0 {
	padding: 0 !important;
}
.mt-0 {
	margin-top: 0px !important;
}
.mt-10 {
	margin-top: 10px !important;
}
.mt-15 {
	margin-top: 15px !important;
}
.mt-20 {
	margin-top: 20px !important;
}
.mb-0 {
	margin-bottom: 0px !important;
}
.mb-10 {
	margin-bottom: 10px !important;
}
.mb-15 {
	margin-bottom: 15px !important;
}
.mb-20 {
	margin-bottom: 20px !important;
}
.pt-0 {
	padding-top: 0px !important;
}
.pt-10 {
	padding-top: 10px !important;
}
.pt-15 {
	padding-top: 15px !important;
}
.pt-20 {
	padding-top: 20px !important;
}
.pb-0 {
	padding-bottom: 0px !important;
}
.pb-10 {
	padding-bottom: 10px !important;
}
.pb-15 {
	padding-bottom: 15px !important;
}
.pb-20 {
	padding-bottom: 20px !important;
}
.border-top {
	border-top: solid 1px #d3dbe2;
	border-top: solid 1px #d3dbe2;
}
.border {
	border: solid 1px #d3dbe2;
}
.no-border {
	border: 0;
}
span.form-text {
	display: block;
}
.full-width {
	width: 100%;
}
.inp-btm-margin {
	margin-bottom: 15px;
}
.overflow-hidden {
	overflow: hidden;
}
.overlay {
	position: relative;
	&:after {
		content: '';
		position: fixed;
		top: 56px;
		left: 0;
		width: 100%;
		height: calc(100vh - 56px);
		background-color: rgba(0, 0, 0, 0.5);
		z-index: 9;
	}
}
.action-icon {
	font-size: 19px;
	margin: 0 12px 0 0;
}
.pos-rel {
	position: relative;
	position: relative;
}
.pos-abl {
	position: absolute;
}
.pos-ver-middle {
	position: absolute;
	top: 50%;
	transform: translateY(-50%);
}
.pos-middle {
	position: absolute;
	top: 50%;
	left: 0;
	right: 0;
	margin: auto;
	transform: translateY(-50%);
}
.heading-underline {
	position: relative;
	margin-bottom: 35px;
	&:after {
		position: absolute;
		content: '';
		width: 57px;
		height: 2px;
		background: #d3d4d5;
		left: 0;
		right: 0;
		margin: auto;
		bottom: -10px;
	}
}
.inline {
	display: inline-block;
}
.inline-top {
	display: inline-block;
	vertical-align: top;
}
.single-order-detail-table {
	table {
		.order-item-img {
			display: inline-block;
			vertical-align: top;
			width: 80px;
			margin-right: 15px;
			text-align: center;
			background: #d2dbe2;
		}
		.order-item-detail {
			display: inline-block;
			vertical-align: top;
		}
		.order-item-img.icon-item {
			padding: 15px 10px;
			font-size: 30px;
		}
		.shipping-row {
			.refund-btn {
				vertical-align: bottom;
			}
		}
		.refund-row {
			td {
				vertical-align: bottom !important;
			}
		}
		.order-thumb {
			width: 100px;
		}
		.item_cost {
			width: 100px;
		}
		.quantity {
			width: 100px;
		}
		.line_cost {
			width: 100px;
		}
		.wcmp-item-commission {
			width: 100px;
		}
		input {
			max-width: 80px;
		}
		table {
			margin-top: 2px;
			td {
				padding: 1px;
			}
			th {
				padding: 1px;
				padding-right: 15px;
				padding-left: 0;
			}
		}
	}
	.table {
		>tbody {
			+ {
				tbody {
					border-top: 1px solid #ddd;
				}
			}
		}
	}
	.wcmp-order-totals {
		td {
			padding-bottom: 10px !important;
		}
	}
	.wc-order-totals {
		td {
			padding-bottom: 10px !important;
		}
	}
	.form-control {
		height: 28px;
	}
}
.inline-middle {
	display: inline-block;
	vertical-align: middle;
}
.change-status {
	.order-status-text {
		i {
			display: inline-block;
			vertical-align: middle;
			display: inline-block;
			width: 30px;
			height: 30px;
			vertical-align: top;
			position: absolute;
			background: #f36f5a;
			z-index: 1;
			margin: -6px 0 0 -36px;
			border-radius: 50%;
			line-height: 30px;
			text-align: center;
			color: #fff;
		}
		span {
			display: inline-block;
			vertical-align: middle;
		}
		background: #fff;
		border: 1px solid #d3dbe2;
		height: 25px;
		padding: 2px 11px 2px 29px;
	}
	margin: 0 0 0 30px;
	.order-status-edit-button {
		margin: 3px 0 0 10px;
		cursor: pointer;
		color: #3f85b9;
		float: left;
	}
	.dropdown-panel {
		margin-top: 8px;
	}
	.wc-pending {
		i {
			background: #f58020;
			&:before {
				content: '\e957';
				margin: 0 0 0 3px;
			}
		}
	}
	.wc-processing {
		i {
			background: #fec40d;
			&:before {
				content: '\e958';
			}
		}
	}
	.wc-on-hold {
		i {
			background: #ce9416;
			&:before {
				content: '\e954';
			}
		}
	}
	.wc-completed {
		i {
			background: #37a972;
			&:before {
				content: '\e950';
			}
		}
	}
	.wc-cancelled {
		i {
			background: #c84040;
			&:before {
				content: '\e94f';
			}
		}
	}
	.wc-refunded {
		i {
			background: #349bd5;
			&:before {
				content: '\e959';
			}
		}
	}
	.wc-failed {
		i {
			background: #f36f59;
			&:before {
				content: '\e954';
			}
		}
	}
	.change-status.loaderOverlay {
		&:after {
			left: -6px;
			top: -3px;
			right: -6px;
			bottom: -3px;
		}
	}
}
.wcmp-panel-loader {
	position: absolute;
	width: 100%;
	height: 100%;
	background: rgba(255, 255, 255, 0.7);
	text-align: center;
	z-index: 9;
	display: none;
	.wcmp-spinner {
		z-index: 2;
		color: #232e2e;
		position: absolute;
		top: 50%;
		transform: translateY(-50%) translateX(-50%);
		right: 50%;
	}
}
.loaderOverlay {
	position: relative;
	cursor: progress;
	&:after {
		position: absolute;
		content: '';
		background: rgba(255, 255, 255, 0.6);
		left: 0;
		top: 0;
		right: 0;
		bottom: 0;
		z-index: 1;
	}
}
hr {
	border-color: #d3dbe2;
}
.table {
	>tbody {
		>tr {
			>td {
				padding: 20px;
			}
		}
	}
	>thead {
		>tr {
			>th {
				padding: 8px 20px;
			}
		}
	}
}
.dataTable.table {
	>thead {
		>tr {
			>th {
				padding: 8px;
			}
		}
	}
}
.table-striped {
	>tbody {
		>tr {
			&:nth-of-type(odd) {
				background-color: #fff;
			}
		}
	}
}
table {
	th {
		border-left: none;
		border-right: none;
		border-collapse: collapse;
		background-color: #fff;
		font-weight: 400;
		font-family: "Open Sans", sans-serif;
		font-size: 14px;
		border-top: 0;
		color: #000;
		input[type=checkbox] {
			border: 2px solid #afadad;
		}
		.checkbox-holder {
			.wcmp-font {
				color: #afafaf;
				background: #fff;
			}
		}
	}
	td {
		border-left: none;
		border-right: none;
		border-collapse: collapse;
	}
	tr {
		background-color: #fff;
	}
	tbody {
		tr {
			&:first-of-type {
				th {
					background: transparent;
				}
			}
		}
		th {
			background-color: #fff;
			font-weight: 400;
			font-family: "Open Sans", sans-serif;
			font-size: 14px;
			border-top: 0;
			color: #000;
		}
	}
	thead {
		th {
			background-color: #fff;
			font-weight: 400;
			font-family: "Open Sans", sans-serif;
			font-size: 14px;
			border-top: 0;
			color: #000;
		}
	}
	input[type="checkbox"] {
		margin: 0 !important;
	}
}
table.table-bordered {
	border: 1px solid #d3dbe2;
	tr {
		th {
			position: relative;
			border-right: 0 !important;
			border-left: 0 !important;
			&:before {
				content: '';
				position: absolute;
				width: 1px;
				height: calc(100% - 12px);
				background: #d3dbe2;
				right: 0;
				top: 0;
				bottom: 0;
				margin: auto;
				z-index: 1;
			}
			&:last-of-type {
				&:before {
					display: none;
				}
			}
		}
	}
	thead {
		th {
			vertical-align: middle;
		}
	}
}
table.table-bordered.no-th-border {
	tr {
		th {
			&:before {
				display: none;
			}
		}
	}
}
@-moz-document {
	url-prefix() {
		table.table-bordered tbody { border-top: solid 2px #d3dbe2;
	}
}
} {
	table.table-outer-border {
		border: 1px solid #ddd;
	}
}
table.table-outer-border {
	.table-outer-border {
		thead {
			th {
				&:last-of-type {
					border-right: 1px solid #ddd;
				}
			}
		}
		tbody {
			td {
				&:last-of-type {
					border-right: 1px solid #ddd;
				}
			}
		}
	}
}
.table-bordered {
	>tbody {
		>tr {
			>td {
				border: 1px solid #d3dbe2;
			}
			>th {
				border: 1px solid #d3dbe2;
			}
		}
	}
	>tfoot {
		>tr {
			>td {
				border: 1px solid #d3dbe2;
			}
			>th {
				border: 1px solid #d3dbe2;
			}
		}
	}
	>thead {
		>tr {
			>td {
				border: 1px solid #d3dbe2;
			}
			>th {
				border: 1px solid #d3dbe2;
			}
		}
	}
}
.top-navbar {
	padding-top: 0;
	padding-bottom: 0;
	position: fixed;
	z-index: 9;
	width: 100%;
	top: 0;
	height: 64px;
	box-shadow: 1px 3px 4px rgba(0, 0, 0, 0.1);
	.navbar {
		height: 100%;
	}
}
.breadcrumb {
	background-color: transparent;
	padding: 0;
	margin: 19px 0 0;
	a {
		color: #626c6f;
		&:hover {
			color: #252525;
		}
	}
	.active {
		color: #fff;
	}
	li {
		&:before {
			display: none;
		}
	}
	>li {
		&:after {
			content: '';
			width: 5px;
			margin: 0 13px 0 17px;
			display: inline-block;
			height: 9px;
			background: url(../../images/breadcrumb-icon.png) no-repeat left center;
			vertical-align: middle;
		}
		&:last-child {
			&:after {
				display: none;
			}
		}
	}
}
.breadcrumb-panel {
	border-left: 6px solid #3f85b9 !important;
}
.panel-body {
	p {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
	>.taxonomy-widget {
		>li {
			&:first-child {
				margin-top: 0;
			}
		}
	}
}
.panel.panel-default.panel-pading {
	padding: 25px;
}
.panel-content-padding {
	padding: 20px !important;
}
.wcmp_vendor_transaction_details {
	.transaction-details {
		.transaction-list {
			li {
				padding: 20px !important;
				border-bottom: 1px solid rgba(255, 255, 255, 0.5);
			}
			padding: 0;
			margin: -20px 0 0;
			list-style: none;
			color: inherit;
			p {
				margin-bottom: 0;
				width: calc(100% - 70px);
				display: inline-block;
				padding-right: 10px;
				.order-id {
					display: block;
					opacity: 0.65;
					a {
						color: inherit;
					}
				}
			}
		}
		div.total-balance-wrap {
			padding: 20px;
		}
		h4 {
			display: inline-block;
			margin: 0;
			color: inherit;
		}
	}
	color: #fff;
	.panel-body {
		background: #3f85b9 !important;
		color: inherit;
		border: 0 !important;
	}
	.panel-footer {
		background: #306fa8 !important;
		border: 0 !important;
		a {
			color: inherit;
		}
	}
	.wcmp_dashboard_widget_total_transaction {
		font-weight: 600;
		color: inherit;
		opacity: 0.65;
		margin-top: 0;
		line-height: 1;
		font-size: 41px;
	}
}
.staticstics-panel-wrap {
	.panel-body {
		padding: 20px !important;
		h2 {
			margin: 20px 0;
		}
		>h2 {
			background: #333b3d;
			color: #fff;
			padding: 16px 20px;
			margin: -16px -16px 5px;
		}
		.short-stat-info-list {
			padding: 0;
			list-style: none;
			margin: 10px 0 0;
			border: 1px solid #d3dbe2;
			&:first-of-type {
				margin: 0;
			}
			li {
				padding: 8px 0;
				border-bottom: 1px solid #d3dbe2;
				overflow: hidden;
				>span {
					width: 28%;
					display: inline-block;
					font-size: 15px;
					vertical-align: middle;
				}
				>span.stat-icon {
					width: 31%;
					text-align: right;
					font-size: 28px;
					padding-right: 37px;
					color: #333332;
				}
				>span.current-stat-report {
					padding: 5px 6px;
					margin: 0 9% 0 0;
				}
				>span.prev-stat-report {
					color: #a6afb2;
				}
				&:last-of-type {
					border: none;
				}
			}
		}
		.stat-detail-info {
			line-height: 22px;
			vertical-align: middle;
			font-size: 15px;
			margin: 0 0 8px;
			i {
				color: #3f85b9;
				font-size: 22px;
				vertical-align: middle;
			}
		}
		.compare-stat-info {
			padding: 20px 25px;
			border: solid 1px #d3dbe2;
			margin: 15px 0;
			position: relative;
			&:after {
				left: 0%;
				top: -1px;
				position: absolute;
				content: '';
				width: 6px;
				background: #3f85b9;
				left: -1px;
				top: -1px;
				bottom: -1px;
			}
			span {
				font-style: italic;
			}
			select {
				margin-left: 10px;
				display: inline-block;
				vertical-align: middle;
			}
		}
		.wcmp-website-stat-list {
			padding: 0;
			list-style: none;
			margin: 0 0 -10px 0;
			overflow: hidden;
			li {
				float: left;
				color: #455053;
				margin: 0 2% 10px 0;
				width: 49%;
				line-height: 24px;
				i {
					font-size: 25px;
					margin-right: 5px;
					vertical-align: middle;
				}
				span {
					display: inline;
					vertical-align: middle;
				}
				&:nth-child(even) {
					margin-right: 0;
				}
				&:nth-child(3) {
					clear: left;
				}
			}
		}
	}
}
.wcmp_vendor_product_stats {
	.panel-body {
		padding: 20px !important;
	}
	.wcmp_product_stats_wrap {
		.p_stats_data {
			margin-top: 10px;
			padding-top: 10px;
			border-top: solid 2px #d4d7db;
			.list-group {
				margin: 0;
				.badge {
					background: #949c9e;
					border-radius: 0;
					float: none;
					position: absolute;
					right: 12px;
					top: 50%;
					transform: translateY(-50%);
				}
			}
		}
		#p_stats_piechart {
			svg {
				overflow: visible !important;
			}
		}
		.list-group {
			li {
				border: 1px solid #d3dbe2;
				margin-bottom: 8px;
				border-radius: 0;
				position: relative;
				.stat-left-border {
					position: absolute;
					top: -1px;
					left: -1px;
					width: 6px;
					bottom: -1px;
				}
				>p {
					width: calc(100% - 25px);
				}
				&:last-child {
					margin-bottom: 0;
				}
			}
		}
		.product-stat-chart {
			display: flex;
			align-items: flex-end;
			justify-content: space-between;
			height: 160px;
			margin-top: 20px;
			.product-stat-bar {
				background: #e0e6eb;
				width: 22%;
				text-align: center;
				height: 100%;
				position: relative;
				.stat-percentage-holder {
					position: absolute;
					width: 100%;
					bottom: 0;
					left: 0;
					&:after {
						position: absolute;
						content: '';
						width: 100%;
						height: 1px;
						background: rgba(255, 255, 255, 0.17);
						left: 0;
						top: 0;
					}
					.stat-percentage-count {
						width: 100%;
						display: inline-block;
						color: #fff;
						position: absolute;
						left: 0;
						top: -22px;
						height: 22px;
						padding: 2px;
					}
				}
			}
		}
	}
}
.wcmp_customer_reviews {
	.wcmp-comments {
		.media-list {
			tr {
				td {
					padding: 20px !important;
					margin: 0;
					border-bottom: solid 1px #d3dbe2;
					.media-heading {
						font-size: 14px;
						color: #000000;
						margin-bottom: 8px;
						small {
							margin-left: 10px;
						}
					}
					a {
						margin-top: 10px;
					}
				}
			}
			margin: 0;
		}
		clear: both;
	}
}
.wcmp-non-vendor-notice {
	margin-top: 55px;
	p {
		margin: 0;
	}
}
input.upload_button {
	font-size: 14px;
	padding: 10px;
	width: 30%;
	margin-bottom: 0;
	vertical-align: middle !important;
	width: 104px;
	height: 45px;
	border: 2px solid #d2d2d2;
	text-align: left;
	background-color: transparent;
	background-repeat: no-repeat;
	background-position: right 10px center;
	background-size: 22px auto;
	background-image: url(../../images/upload-icon.png);
	&:focus {
		outline: none;
	}
	&:hover {
		border-color: #bbb5b5;
	}
}
input.remove_button {
	font-size: 14px;
	padding: 10px;
	width: 30%;
	margin-bottom: 0;
	vertical-align: middle !important;
	width: 104px;
	height: 45px;
	border: 2px solid #d2d2d2;
	text-align: left;
	background-color: transparent;
	background-repeat: no-repeat;
	background-position: right 10px center;
	background-size: 22px auto;
	background-image: url(../../images/delete-icon.png);
	&:focus {
		outline: none;
	}
	&:hover {
		border-color: #bbb5b5;
	}
}
.wcmp_shop_settings_form {
	.panel.panel-default {
		&:last-of-type {
			margin-bottom: 0;
		}
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.wcmp_policy_form {
	.panel.panel-default {
		&:last-of-type {
			margin-bottom: 0;
		}
		&:first-of-type {
			margin-top: 0;
		}
	}
	.panel-body {
		.form-group {
			&:last-of-type {
				margin-bottom: 0;
				.form-group {
					margin-bottom: 0;
				}
			}
		}
	}
}
.col-lg-8 {
	.panel.panel-default {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.col-lg-4 {
	.panel.panel-default {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.form-inner {
	.panel.panel-default {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
#wrapper {
	width: 100%;
	overflow-x: hidden;
}
#page-wrapper {
	min-height: calc(100vh - 64px);
	background: #edf0f1;
	transition: all .4s;
}
.panel.panel-default {
	border: none;
	padding: 18px 20px 20px;
	margin: 35px 0 0;
	border-radius: 0;
	transition: all 0.3s;
	.panel-heading {
		color: #252525;
		background-color: transparent;
		border-color: transparent;
		padding: 0 0 12px;
		border-bottom: 1px solid #e6e7e8;
		margin: 0 0 20px;
		overflow: hidden;
		h3 {
			margin: 0;
		}
		h1 {
			margin-bottom: 7px;
		}
	}
	.panel-body {
		padding: 0;
		table {
			&:last-of-type {
				margin-bottom: 0;
			}
		}
	}
	&:hover {
		box-shadow: 1px 1px 6px rgba(0, 0, 0, 0.2);
	}
	.panel-footer {
		margin: 15px -20px 0;
		border-top: 1px solid #e6e7e8;
		padding: 20px 20px 0;
		overflow: hidden;
		background: transparent;
		i {
			font-size: 9px;
			margin: 0 0 2px 0;
			display: inline-block;
			vertical-align: middle;
		}
	}
}
.panel.panel-default.pannel-outer-heading {
	padding: 0;
	background-color: transparent;
	box-shadow: none;
	.panel-heading {
		border: none;
		padding: 0;
		margin: 0 0 12px;
	}
	.panel-body {
		background-color: #fff;
		padding: 0;
		border: 1px solid #d3dbe2;
	}
	.panel-footer {
		background-color: #fff;
		margin: 0;
		padding: 14px 20px;
		border: 1px solid #d3dbe2;
		border-top: 0;
	}
}
.panel-custom {
	border: 1px solid #d3dbe2;
	border-radius: 0;
	.panel-heading {
		background-color: #eff1f5;
		color: #252525;
		border-bottom: 1px solid #d3dbe2;
		padding: 14px 20px;
	}
	.panel-body {
		padding: 20px;
	}
}
.wcmp_vendor_pending_shipping {
	.panel-body {
		border: 0 !important;
	}
	.table-bordered {
		>thead {
			>tr {
				>th {
					white-space: nowrap;
				}
			}
		}
	}
	table {
		tbody {
			tr {
				td {
					&:last-of-type {
						vertical-align: middle;
						i {
							font-size: 21px;
							margin: 0;
						}
					}
				}
			}
		}
	}
}
.wcmp_vendor_product_sales_report {
	.panel-body {
		border: 0 !important;
	}
}
mark {
	padding: 0 7px 2px;
	font-weight: 600;
}
mark.mark-green {
	background: #42b64d;
	color: #fff;
}
mark.mark-red {
	background: #e55959;
	color: #fff;
}
.card-header {
	font-size: 22px;
	border-bottom: 1px solid #ccc;
	margin-bottom: 15px;
}
.woocommerce-message {
	padding: 15px;
	border: 1px solid #d6e9c6;
	border-radius: 4px;
	color: #3c763d !important;
	background-color: #dff0d8;
	margin-bottom: 20px;
}
.woocommerce-info {
	padding: 15px;
	border: 1px solid #bce8f1;
	border-radius: 4px;
	color: #31708f;
	background-color: #d9edf7;
	margin-bottom: 20px;
}
.message-warning {
	padding: 15px;
	border: 1px solid #faebcc;
	border-radius: 4px;
	color: #8a6d3b;
	background-color: #fcf8e3;
}
.woocommerce-error {
	padding: 15px;
	border: 1px solid #ebccd1;
	border-radius: 4px;
	color: #a94442;
	background-color: #f2dede;
	margin-bottom: 20px;
	list-style-type: disc;
	list-style-position: inside;
	&:focus {
		outline: none;
		box-shadow: none;
	}
	div {
		display: inline-block;
		vertical-align: top;
		width: auto !important;
		padding: 0;
	}
	li {
		&:not(:first-child) {
			margin-top: 5px;
		}
	}
}
.notice-wrapper {
	.message-container.container {
		width: 100%;
	}
}
.wcmp-action-container {
	position: fixed;
	top: 78px;
	right: 31px;
	z-index: 8;
	.btn {
		margin-top: 0 !important;
		margin-bottom: 0;
		height: auto;
		float: left;
		margin-left: 10px;
		i {
			color: #fff;
			font-size: 16px;
			vertical-align: middle;
			margin-right: 5px;
			&:before {
				color: #fff;
			}
		}
	}
}
.add-product {
	#wcmp_auto_suggest_product_title {
		ul {
			padding: 0;
			margin: -1px 0 0;
			font-size: 14px;
			text-align: left;
			list-style: none;
			background-color: #fff;
			-webkit-background-clip: padding-box;
			background-clip: padding-box;
			border: 1px solid #ccc;
			border: 1px solid rgba(0, 0, 0, 0.15);
			border-radius: 4px;
			-webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
			box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
			a {
				display: block;
				padding: 5px 20px;
				clear: both;
				color: #333;
				white-space: nowrap;
				&:hover {
					background: #202627;
					color: #fff;
				}
			}
			li.wcmp_no-suggesion {
				display: block;
				padding: 5px 20px;
				clear: both;
				color: #333;
				white-space: nowrap;
			}
		}
	}
}
.nav {
	.open {
		>a {
			background-color: transparent;
			border-color: transparent;
			&:focus {
				background-color: transparent;
				border-color: transparent;
			}
			&:hover {
				background-color: transparent;
				border-color: transparent;
			}
		}
	}
	>li {
		>a {
			&:focus {
				text-decoration: none;
				background-color: transparent;
			}
			&:hover {
				text-decoration: none;
				background-color: transparent;
			}
		}
	}
}
.navbar-default {
	.navbar-collapse {
		border: none;
	}
	.navbar-form {
		border: none;
	}
	border: none;
	position: relative;
	.navbar-toggle {
		border: none;
		background: transparent !important;
		display: block !important;
		left: 284px;
		top: -64px;
		margin: 0;
		border-right: 1px solid #dbdedf;
		border-radius: 0;
		padding: 0 20px;
		height: 64px;
		.icon-bar {
			width: 25px;
			-webkit-transition: all 0.2s;
			transition: all 0.2s;
			background-color: #3f85b9;
			margin-top: 7px;
			&:first-child {
				margin: 0;
			}
		}
		&:hover {
			background: transparent !important;
		}
	}
}
.tab-content {
	>.active {
		opacity: 1;
	}
}
.form-group {
	margin-bottom: 20px;
	overflow: hidden;
	label {
		font-weight: 400;
		color: #565656;
	}
}
label.nolabel {
	visibility: hidden !important;
	padding: 0 !important;
	height: 0;
}
.wcmp_form1 {
	.form-group {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.form-group-wrapper {
	.form-group {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.form-control {
	border-color: #c5c5c5;
	max-width: 100%;
	padding: 3px 5px 4px;
	box-shadow: none;
	line-height: 20px;
}
button.button {
	padding: 3px 5px 4px;
	box-shadow: none;
	line-height: 20px;
}
button.btn {
	padding: 3px 5px 4px;
	box-shadow: none;
	line-height: 20px;
}
select.input-sm {
	padding: 3px 5px 4px;
	box-shadow: none;
	line-height: 20px;
	height: 34px;
}
.compare-stat-info {
	select.form-control {
		width: auto;
	}
}
.pagination {
	>.active {
		>a {
			z-index: 2;
			&:focus {
				z-index: 2;
			}
			&:hover {
				z-index: 2;
			}
		}
		>span {
			z-index: 2;
			&:focus {
				z-index: 2;
			}
			&:hover {
				z-index: 2;
			}
		}
	}
	margin: 13px 0 13px 20px;
	li {
		display: inline-block;
		margin-right: 4px;
		vertical-align: middle;
		a {
			padding: 0 6px;
			border-radius: 0 !important;
			border: 1px solid #d3dbe2;
		}
	}
	li.active {
		a {
			background: #3f85b9;
		}
	}
}
.btn.btn-default {
	color: #fff;
	background-color: #3f85b9;
	border-color: #3f85b9;
	padding: 6px 27px;
	transition: all 0.4s;
	border-radius: 1px;
	box-shadow: inset 0 -1px 3px rgba(0, 0, 0, 0.2);
	&:hover {
		background-color: #202627;
		border-color: #202627;
		color: #fff;
		outline: none;
	}
	&:active {
		background-color: #202627;
		border-color: #202627;
		color: #fff;
		outline: none;
		&:focus {
			outline: none;
		}
	}
	&:focus {
		outline: none;
	}
}
.btn.btn-secondary {
	color: #fff;
	background-color: #3f85b9;
	border-color: #3f85b9;
	padding: 6px 27px;
	transition: all 0.4s;
	border-radius: 1px;
	box-shadow: inset 0 -1px 3px rgba(0, 0, 0, 0.2);
	padding-right: 10px;
	padding-left: 10px;
	&:hover {
		background-color: #202627;
		border-color: #202627;
		color: #fff;
		outline: none;
	}
	&:active {
		background-color: #202627;
		border-color: #202627;
		color: #fff;
		outline: none;
		&:focus {
			outline: none;
		}
	}
	&:focus {
		outline: none;
	}
}
.btn.btn-default.btn-sm {
	font-size: 14px;
	padding: 4px 12px;
}
.btn.btn-secondary.btn-sm {
	font-size: 14px;
	padding: 4px 12px;
}
.pro_ele_block {
	.form-group {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.multi_input_block {
	.form-group {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
	label {
		font-size: 14px;
	}
	label.vari_select_lbl {
		+ {
			select {
				width: 69%;
				margin: 0 0 0 3%;
				display: inline-block;
			}
		}
	}
	border: 1px solid #dfdfdf;
	border-radius: 10px;
	border-radius: 10px;
	-moz-border-radius: 10px;
	-webkit-border-radius: 10px;
	padding: 10px;
	margin-bottom: 10px;
}
textarea {
	resize: none;
}
.form-horizontal {
	.control-label {
		position: relative;
		text-align: left;
		padding-top: 6px;
		font-size: 14px;
		line-height: 18px;
		word-wrap: break-word;
		.img_tip {
			position: absolute;
			top: 0;
			right: 0;
			margin: 10px -5px 0 0;
		}
	}
	.form-group {
		.checkbox-holder {
			margin-top: 5px;
		}
		input[type="checkbox"] {
			margin-top: 0;
		}
	}
	.checkbox {
		min-height: 22px;
	}
	.radio {
		min-height: 22px;
	}
}
.woocommerce {
	table.form-table {
		select {
			height: 90px !important;
			padding: 5px;
		}
	}
}
.woocommerce-exporter-category {
	border-radius: 4px;
}
blockquote {
	background: #fff;
	border-left: 5px solid #3f85b9;
}
.modal-title {
	width: calc(100% - 25px);
	display: inline-block;
	vertical-align: top;
}
#wcmp-afm-bulk-edit-form {
	.form-group {
		margin-bottom: 10px;
	}
}
.star-rating {
	text-align: left;
	font-size: 21px;
	overflow: hidden;
	position: relative;
	height: 1em;
	line-height: 1.2em;
	width: 6em;
	font-family: 'dashicons';
	margin: 0 0 25px;
	float: left;
	&:before {
		content: "\f154 \f154 \f154 \f154 \f154";
		color: #ddd;
		float: left;
		top: 0;
		left: 0;
		position: absolute;
		color: #3f85b9;
	}
	span {
		overflow: hidden;
		float: left;
		top: 0;
		left: 0;
		position: absolute;
		padding-top: 1.5em;
		font-weight: normal;
		&:before {
			content: "\f155 \f155 \f155 \f155 \f155";
			color: #888;
			top: 0;
			position: absolute;
			left: 0;
			color: #3f85b9;
		}
	}
}
.taxonomy-widget {
	padding: 0;
	margin: 0;
	max-height: 200px;
	overflow: auto;
	label {
		margin: 0;
	}
	li {
		margin-top: 13px;
	}
	ul {
		padding: 0 0 0 15px;
	}
}
.media-body {
	h4.media-heading {
		color: #3f85b9;
	}
	a {
		color: #3f85b9;
		margin-top: 2px;
		display: inline-block;
		&:hover {
			color: #000;
		}
	}
}
#ui-datepicker-div {
	z-index: 9 !important;
}
.ui-widget-content {
	color: #626c6f;
}
.progress {
	height: 27px;
	background-color: #4c4c4c;
	.progress-bar {
		font-size: 13px;
		line-height: 27px;
	}
}
ul.category-filter-nav {
	li {
		margin-right: 10px;
		a {
			padding: 0 5px;
			position: relative;
			font-size: 13px;
			&:after {
				position: absolute;
				content: '|';
				top: 0;
				right: 0;
				margin: -1px -10px 0 0;
				color: #696969;
			}
		}
		&:last-of-type {
			margin-right: 0;
			a {
				&:after {
					content: '';
				}
			}
		}
	}
}
.col-actions {
	i {
		font-size: 17px;
		vertical-align: middle;
	}
}
div.dataTables_wrapper {
	div.dataTables_processing {
		box-shadow: 1px 1px 10px #423c3c;
		background: #fff;
	}
	div.dataTables_length {
		select {
			margin: 0 10px;
		}
		select.wcmp_filter_product_cat {
			width: auto;
			margin: 0 0 0 5px;
		}
		select.wcmp-filter-dtdd {
			width: auto;
			margin: 0;
		}
		select.wcmp_filter_bookings {
			width: auto;
		}
	}
}
html {
	div.dataTables_wrapper {
		div.dataTables_filter {
			input {
				width: 170px;
				max-width: calc(100% - 55px);
			}
		}
	}
}
table.dataTable {
	&:not(.wcmp-widget-dt) {
		font-size: 13px;
		border-color: #b4c1cc;
		margin: 15px 0 !important;
		thead {
			th {
				font-size: 14px;
				background-color: #d3dbe2;
				color: #000;
				border-right: solid 1px #b4c1cc !important;
				&:last-of-type {
					border: 0 !important;
				}
			}
			th.price {
				min-width: 52px;
			}
		}
		tfoot {
			th {
				font-size: 14px;
				background-color: #d3dbe2;
				color: #000;
				border-right: solid 1px #b4c1cc !important;
				&:last-of-type {
					border: 0 !important;
				}
			}
			th.price {
				min-width: 52px;
			}
		}
		tbody {
			td {
				padding: 10px;
				border-color: #b4c1cc;
			}
			td.name {
				>a {
					font-size: 14px;
					font-family: "Open Sans", sans-serif;
				}
				.row-actions {
					margin-top: 5px;
					span.divider {
						display: inline-block;
						vertical-align: top;
						font-size: 11px;
						color: #8c8c8c;
						font-family: "Open Sans", sans-serif;
					}
				}
			}
			td.price {
				ins {
					display: block;
				}
			}
		}
	}
	>tbody {
		>tr.child {
			ul.dtr-details {
				width: 100%;
				>li {
					&:last-child {
						padding-bottom: 0;
					}
				}
			}
		}
	}
	tbody {
		td.image {
			img {
				min-width: 25px;
			}
			width: 40px;
		}
		td.name {
			width: 33%;
		}
		td.price {
			max-width: 85px;
		}
		td.stock {
			width: 63px;
			.label {
				color: #fff;
			}
		}
		td.date {
			width: 130px;
		}
		td.status {
			width: 70px;
		}
	}
	th.image {
		text-align: center;
	}
	.wcmp-font.ico-image-icon {
		font-size: 22px;
		vertical-align: middle;
		color: #000;
	}
	tr {
		th.sorting_asc {
			padding-right: 10px !important;
		}
	}
}
.dtr-details {
	.dtr-title {
		display: inline-block;
		vertical-align: middle;
	}
	.dtr-data {
		display: inline-block;
		vertical-align: middle;
	}
}
table.dataTable.table {
	border-collapse: collapse !important;
}
table.dataTable.dtr-inline.collapsed {
	>thead {
		>tr {
			>th {
				&:first-child {
					position: relative;
					padding-left: 33px;
					cursor: pointer;
				}
			}
		}
	}
}
.vendor-product {
	&:hover {
		.row-actions {
			visibility: visible;
		}
	}
}
span.delete {
	a {
		color: #a00;
	}
}
.product_filters {
	.by_status {
		list-style: none;
		margin: 0;
		padding: 0;
		font-size: 14px;
		color: #666;
	}
	li {
		display: inline-block;
		margin: 0;
		padding: 0;
		white-space: nowrap;
		a.current {
			color: #000;
			font-weight: 600;
			border: none;
		}
	}
	line-height: 0.7;
	margin-top: 13px;
}
.screen-reader-text {
	border: 0;
	clip: rect(1px, 1px, 1px, 1px);
	-webkit-clip-path: inset(50%);
	clip-path: inset(50%);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
	word-wrap: normal !important;
	border: 0;
	clip: rect(1px, 1px, 1px, 1px);
	-webkit-clip-path: inset(50%);
	clip-path: inset(50%);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
	word-wrap: normal !important;
	span {
		border: 0;
		clip: rect(1px, 1px, 1px, 1px);
		-webkit-clip-path: inset(50%);
		clip-path: inset(50%);
		height: 1px;
		margin: -1px;
		overflow: hidden;
		padding: 0;
		position: absolute;
		width: 1px;
		word-wrap: normal !important;
		border: 0;
		clip: rect(1px, 1px, 1px, 1px);
		-webkit-clip-path: inset(50%);
		clip-path: inset(50%);
		height: 1px;
		margin: -1px;
		overflow: hidden;
		padding: 0;
		position: absolute;
		width: 1px;
		word-wrap: normal !important;
	}
}
.ui-helper-hidden-accessible {
	border: 0;
	clip: rect(1px, 1px, 1px, 1px);
	-webkit-clip-path: inset(50%);
	clip-path: inset(50%);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
	word-wrap: normal !important;
	border: 0;
	clip: rect(1px, 1px, 1px, 1px);
	-webkit-clip-path: inset(50%);
	clip-path: inset(50%);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
	word-wrap: normal !important;
}
#media-attachment-date-filters {
	margin-left: 10px;
}
.date-inp-wrap {
	position: relative;
	display: inline-block;
	vertical-align: middle;
	&:after {
		content: '\e908';
		font-family: 'wcmp' !important;
		font-size: 19px;
		position: absolute;
		right: 10px;
		top: 50%;
		transform: translateY(-50%);
		color: #737377;
		pointer-events: none;
	}
	&:before {
		content: '';
		position: absolute;
		top: 0;
		right: 37px;
		width: 1px;
		height: 100%;
		background: #d3dbe2;
		pointer-events: none;
	}
	.hasDatepicker {
		padding-right: 40px;
		padding-right: 40px;
		width: 165px;
		padding-left: 15px;
	}
}
.wcmp-modal {
	* {
		box-sizing: border-box;
	}
	.wcmp-modal-content {
		position: fixed;
		background: #fff;
		z-index: 100000;
		left: 50%;
		top: 50%;
		-webkit-transform: translate(-50%, -50%);
		-ms-transform: translate(-50%, -50%);
		transform: translate(-50%, -50%);
		max-width: 100%;
		min-width: 500px;
		article {
			overflow: auto;
			max-height: 72vh;
		}
	}
	.wc-shipping-zone-method-selector {
		.wc-shipping-zone-method-description {
			margin: .75em 1px 0;
			line-height: 1.5em;
			color: #999;
			font-style: italic;
		}
	}
}
.wcmp-modal-dialog {
	position: fixed;
	background: rgba(0, 0, 0, 0.7);
	left: 0;
	right: 0;
	top: 0;
	bottom: 0;
	z-index: 1000;
}
.wcmp-modal-main {
	.wcmp-modal-header {
		h1 {
			margin: 0;
			font-size: 18px;
			font-weight: 700;
			line-height: 1.5em;
			color: #23282d;
		}
		height: auto;
		background: #fcfcfc;
		padding: 1em 1.5em;
		border-bottom: 1px solid #ddd;
		.modal-close-link {
			cursor: pointer;
			color: #777;
			height: 54px;
			width: 54px;
			padding: 0;
			position: absolute;
			top: 0;
			right: 0;
			text-align: center;
			border: 0;
			border-left: 1px solid #ddd;
			background-color: transparent;
			-webkit-transition: color .1s ease-in-out,background .1s ease-in-out;
			transition: color .1s ease-in-out,background .1s ease-in-out;
			&::before {
				font: normal 22px/50px dashicons !important;
				color: #666;
				display: block;
				content: '\f335';
				font-weight: 300;
			}
		}
	}
	padding-bottom: 55px;
	article {
		display: block;
		position: relative;
		padding: 1.5em;
		p {
			&:first-child {
				margin-top: 0;
			}
			margin: 1.5em 0;
		}
	}
	header {
		display: block;
		position: relative;
	}
	footer {
		position: absolute;
		left: 0;
		right: 0;
		bottom: 0;
		z-index: 100;
		padding: 1em 1.5em;
		background: #fcfcfc;
		border-top: 1px solid #dfdfdf;
		box-shadow: 0 -4px 4px -4px rgba(0, 0, 0, 0.1);
		.inner {
			text-align: right;
			line-height: 23px;
		}
	}
}
.navbar {
	min-height: auto;
	margin: 0;
	background: transparent;
	.topbar-left {
		height: 100%;
		width: 284px;
		background: #3f85b9;
		.toggle-sidemenu {
			display: inline-block;
			vertical-align: middle;
		}
		.site-logo {
			display: inline-block;
			vertical-align: middle;
			a {
				display: block;
				color: #fff;
			}
			img {
				max-width: 95%;
				max-height: 45px;
				vertical-align: -webkit-baseline-middle;
			}
		}
	}
}
ul.nav {
	.login-user {
		position: relative;
		a {
			i {
				font-size: calc(26px - 3px);
				color: #677072;
				vertical-align: middle;
			}
			span {
				i {
					font-size: 11px;
					height: auto;
					width: auto;
					color: #626c6f;
				}
			}
			&:hover {
				i {
					color: #3f85b9;
				}
			}
		}
		.dropdown-menu.dropdown-user {
			width: 208px;
			padding: 0;
			z-index: 9999;
			border: solid 4px #fff;
			border-radius: 0;
			margin: 1px 26px 0 0;
			a {
				padding: 7px 15px;
				margin: 0;
				&:hover {
					background-color: transparent;
					color: #3f85b9;
				}
				&:focus {
					background: none;
				}
			}
			i {
				font-size: 22px;
				vertical-align: middle;
				display: inline-block;
				margin-right: 12px;
				+ {
					span {
						vertical-align: middle;
						display: inline-block;
					}
				}
			}
			li {
				&:not(.sidebar-logo) {
					margin: 5px 0;
				}
			}
		}
	}
}
.navbar-top-links {
	margin-right: 0;
	li {
		display: inline-block;
		a {
			color: #677072;
			position: relative;
			padding: 10px;
			min-height: 50px;
			transition: all 0.3s;
			&:hover {
				color: #3f85b9;
			}
			i {
				font-size: 26px;
				color: #737373;
				display: inline-block;
				vertical-align: middle;
				margin-right: 6px;
			}
			span {
				display: inline-block;
				vertical-align: middle;
				font-size: 15px;
				text-transform: capitalize;
			}
		}
	}
	li.login-user {
		margin-left: 18px;
		position: relative;
		padding-left: 20px;
		&:before {
			content: '';
			height: 100%;
			width: 1px;
			position: absolute;
			top: 0;
			left: 0;
			background-color: #f1f3f6;
		}
		.dropdown-menu.dropdown-user {
			min-width: 225px;
			padding: 0 0 8px;
		}
	}
	li.notification-link {
		margin: 0 40px 0 0;
		a {
			padding: 0;
			min-height: auto;
			display: inline-block;
			min-height: initial;
			&:hover {
				color: #3f85b9;
				i {
					color: #3f85b9;
				}
			}
		}
		.notification-blink {
			position: absolute;
			background-color: #e61818;
			border-radius: 23px;
			min-width: 20px;
			min-height: 20px;
			top: -13px;
			left: 14px;
			text-align: center;
			color: #fff;
			padding: 1px 4px;
			width: auto;
			box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.3);
			pointer-events: none;
		}
	}
	.login-user {
		span {
			vertical-align: middle;
			margin-left: 2px;
			i {
				font-size: 13px;
				margin: 3px 0 0;
				line-height: 13px;
				width: auto;
				height: auto;
			}
		}
		a.dropdown-toggle {
			margin-top: 5px;
			padding: 18px 0 23px;
		}
	}
	.dropdown-menu {
		li {
			display: block;
			&:last-child {
				margin-right: 0;
			}
			a {
				padding: 3px 20px;
				min-height: 0;
				div {
					white-space: normal;
				}
			}
		}
	}
	.dropdown-messages {
		width: 310px;
		min-width: 0;
		margin-left: 5px;
	}
	.dropdown-tasks {
		width: 310px;
		min-width: 0;
		margin-left: -59px;
	}
	.dropdown-alerts {
		width: 310px;
		min-width: 0;
		margin-left: -123px;
	}
	.dropdown-user {
		right: 0;
		left: auto;
	}
}
.navbar-top-links.nav {
	>li {
		>a {
			&:hover {
				background: transparent;
			}
			&:focus {
				background: transparent;
			}
		}
	}
	.open {
		a {
			background-color: transparent;
			&:focus {
				background-color: transparent;
			}
			&:hover {
				background-color: transparent;
			}
		}
	}
}
.top-user-nav {
	height: 100%;
	width: 100px;
	>li {
		height: 100%;
		a.dropdown-toggle {
			height: 100%;
			padding: 20px;
			background: #202627;
			text-align: center;
			i.ico-user-icon {
				color: #fff;
			}
			span {
				i {
					color: #6d7677;
					margin-left: 7px;
				}
			}
			&:active {
				background: #202627 !important;
			}
			&:hover {
				background: #202627 !important;
			}
			&:focus {
				background: #202627 !important;
			}
		}
	}
}
.btm-nav-fixed {
	margin-top: 19px;
}
.sidebar {
	color: #9a9a9a;
	background-color: #333b3d;
	height: calc(100vh - 64px);
	.sidebar-nav.navbar-collapse {
		padding-left: 0;
		padding-right: 0;
	}
	.mCustomScrollbar {
		height: calc(100vh - 64px);
	}
	.submenu {
		li {
			border-bottom: none !important;
			margin-top: 5px;
			a {
				padding-left: 51px;
			}
		}
	}
	.nav-third-level {
		li {
			border-bottom: none !important;
			margin-top: 5px;
			a {
				padding-left: 52px;
			}
		}
	}
}
.sidebar.navbar-default {
	li {
		&:not(:first-of-type) {
			margin-top: 1px;
		}
	}
	a {
		color: inherit;
		padding: 14px 55px 14px 35px;
		font-size: 15px;
		line-height: 1;
		position: relative;
	}
	ul {
		a {
			i {
				font-size: 22px;
				vertical-align: middle;
				margin-right: 9px;
				color: inherit;
			}
			&:hover {
				i {
					color: #3f85b9;
				}
			}
			i.ico-downarrow-2-icon {
				float: right;
				margin-top: 2px;
				font-size: 14px;
				line-height: 22px;
				margin: 0 8px 0 0;
				position: absolute;
				right: 16px;
			}
		}
		a.active {
			i {
				color: #3f85b9;
			}
		}
		li {
			a {
				i {
					+ {
						span {
							vertical-align: middle;
						}
					}
				}
			}
		}
	}
}
.sidebar-logo {
	padding: 14px;
	background-color: #d3dbe2;
	h4 {
		color: inherit;
		font-weight: 500;
		color: #455053;
		margin: 12px 0 0;
		text-transform: uppercase;
		word-wrap: break-word;
	}
	a {
		padding: 0;
		font-size: 13px;
		&:hover {
			background: transparent !important;
			color: #2eb1f7 !important;
		}
		&:focus {
			background: transparent !important;
			color: #2eb1f7 !important;
		}
		&:active {
			background: transparent !important;
			color: #2eb1f7 !important;
		}
	}
	.vendor-profile-pic-holder {
		position: relative;
		display: inline-block;
		max-width: 90%;
		img {
			max-height: 100%;
			max-height: 80px;
		}
	}
}
.navbar-default.sidebar {
	ul {
		li {
			a.active {
				background-color: #202627;
				color: #fff;
			}
		}
		ul {
			li {
				a {
					padding: 10px 30px 10px 85px;
					color: #aeb2b7;
					text-transform: none;
					&:hover {
						color: #fff;
						background-color: transparent !important;
					}
					&:focus {
						color: #fff;
						background-color: transparent !important;
					}
				}
				a.active {
					color: #fff;
					background: transparent !important;
				}
			}
			margin-top: 5px;
			margin-bottom: 15px;
		}
	}
	a {
		&:hover {
			background-color: #202627;
			color: #fff;
		}
		&:focus {
			background-color: #202627;
			color: #fff;
		}
	}
}
#page-wrapper.large {
	margin-left: 0;
}
.side-collapse-container {
	position: relative;
	left: 0;
	transition: left .4s;
	overflow-x: hidden;
}
.side-collapse-container.out {
	left: 284px;
}
.side-collapse {
	width: 284px;
	top: 0;
	bottom: 0;
	left: 0;
	position: absolute;
	transition: left .4s;
}
.side-collapse.in {
	left: -284px;
}
.hasmenu {
	ul {
		display: none;
	}
}
.side-collapse-container.large {
	.current-endpoint-title-wrapper {
		left: 0;
	}
}
.side-collapse-container.overlay {
	.current-endpoint-title-wrapper {
		min-width: 300px;
	}
}
.navbar-static-top {
	position: fixed;
	top: 64px;
}
body.admin-bar {
	.top-navbar {
		top: 32px;
	}
	.current-endpoint-title-wrapper {
		top: 96px;
	}
	.navbar-static-top {
		top: 96px;
	}
	.wcmp-action-container {
		top: 110px;
	}
}
.wcmp-color-scheme-outer_space_blue {
	.navbar {
		.topbar-left {
			background: #3f85b9;
		}
	}
	.navbar-default {
		.navbar-toggle {
			.icon-bar {
				background: #3f85b9;
			}
		}
	}
	.staticstics-panel-wrap {
		.panel-body {
			.compare-stat-info {
				&:after {
					background: #3f85b9;
					color: #3f85b9;
				}
			}
			.stat-detail-info {
				i {
					color: #3f85b9;
				}
			}
			>h2 {
				background: #333b3d;
			}
		}
	}
	.progress-bar {
		background: #3f85b9;
	}
	table.dataTable.dtr-inline.collapsed {
		>tbody {
			>tr[role="row"] {
				>td {
					&:first-child {
						&:before {
							background: #3f85b9;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #3f85b9;
						}
					}
				}
			}
			>tr.parent {
				>td {
					&:first-child {
						&:before {
							background: #333b3d;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #333b3d;
						}
					}
				}
			}
		}
	}
	input[type=radio] {
		&:checked {
			&:before {
				background: #3f85b9;
			}
		}
	}
	.navbar-default.sidebar {
		ul {
			li {
				a.active {
					background-color: #202528;
					color: #fff;
				}
			}
		}
		a {
			&:hover {
				background-color: #202528;
				color: #fff;
			}
			&:focus {
				background-color: #202528;
				color: #fff;
			}
		}
	}
	.sidebar {
		background: #333b3d;
		color: #bcb7b2;
		a.active {
			i {
				color: #e9e4e0;
			}
		}
	}
	.vendor-cover-wrap {
		.cover-pic-button {
			button {
				color: #fff;
				background-color: #3f85b9;
				border-color: #3f85b9;
			}
		}
		.vendor-profile-pic-wraper {
			.profile-pic-btn {
				color: #fff;
				background-color: #3f85b9;
				border-color: #3f85b9;
			}
		}
	}
	.woocommerce-exporter-wrapper {
		.button {
			color: #fff;
			background-color: #3f85b9;
			border-color: #3f85b9;
		}
		.wc-progress-steps {
			li.active {
				border-color: #3f85b9 !important;
				color: #3f85b9 !important;
				&::before {
					border-color: #3f85b9 !important;
				}
			}
		}
	}
	.woocommerce-importer-wrapper {
		.button {
			color: #fff;
			background-color: #3f85b9;
			border-color: #3f85b9;
		}
		.wc-progress-steps {
			li.active {
				border-color: #3f85b9 !important;
				color: #3f85b9 !important;
				&::before {
					border-color: #3f85b9 !important;
				}
			}
		}
	}
	.woocommerce-progress-form-wrapper {
		.button {
			color: #fff;
			background-color: #3f85b9;
			border-color: #3f85b9;
		}
		.wc-progress-steps {
			li.active {
				border-color: #3f85b9 !important;
				color: #3f85b9 !important;
				&::before {
					border-color: #3f85b9 !important;
				}
			}
		}
	}
	.btn.btn-default {
		color: #fff;
		background-color: #316fa8;
		border-color: #316fa8;
	}
	.btn.btn-secondary {
		color: #fff;
		background-color: #333b3d;
		border-color: #333b3d;
	}
	.pagination {
		li.active {
			a {
				background: #3f85b9;
				border-color: #3f85b9;
			}
		}
	}
	a {
		color: #3f85b9;
		&:hover {
			color: #333b3d;
		}
	}
	.media-body {
		a {
			color: #3f85b9;
			&:hover {
				color: #333b3d;
			}
		}
	}
	.sidebar.navbar-default {
		ul {
			a {
				&:hover {
					i {
						color: #3f85b9;
						color: #3f85b9;
					}
				}
			}
			a.active {
				i {
					color: #3f85b9;
					color: #3f85b9;
				}
			}
		}
	}
	.navbar-top-links {
		li.notification-link {
			a {
				&:hover {
					color: #3f85b9;
					i {
						color: #3f85b9;
					}
				}
			}
		}
		li {
			a {
				&:hover {
					color: #3f85b9;
				}
			}
		}
	}
	ul.nav {
		.login-user {
			a {
				&:hover {
					i {
						color: #3f85b9;
					}
				}
			}
			.dropdown-menu.dropdown-user {
				a {
					&:hover {
						color: #3f85b9;
					}
				}
			}
		}
	}
	.transaction-list {
		color: #3f85b9;
	}
	.product-import.wcmp_displaybox2m {
		h3 {
			color: #3f85b9;
		}
	}
	.wcmp_displaybox2 {
		h3 {
			color: #3f85b9;
		}
	}
	input[type=checkbox] {
		&:checked {
			&:before {
				color: #3f85b9;
			}
		}
	}
	.wcmp_vendor_transaction_details {
		color: #fff;
		.panel-body {
			background: #3f85b9 !important;
		}
		.panel-footer {
			background: #316fa8 !important;
			a {
				color: #fff;
			}
		}
	}
	.top-user-nav {
		>li {
			a.dropdown-toggle {
				background: #333b3d;
			}
		}
	}
	.current-stat-report {
		color: #316fa8;
		background: rgba(49, 111, 168, 0.15);
	}
	.product-tab-nav-holder {
		ul {
			li.active {
				a {
					border-top-color: #3f85b9;
					&:hover {
						border-top-color: #3f85b9;
					}
					&:focus {
						border-top-color: #3f85b9;
					}
				}
			}
		}
	}
	.primary-color {
		color: #3f85b9;
	}
	.wcmp-vendor-ledger-report-row {
		.bg-ledger {
			background: #3f85b9;
		}
	}
}
.wcmp-color-scheme-green_lagoon {
	.navbar {
		.topbar-left {
			background: #009788;
		}
	}
	.navbar-default {
		.navbar-toggle {
			.icon-bar {
				background: #009788;
			}
		}
	}
	.staticstics-panel-wrap {
		.panel-body {
			.compare-stat-info {
				&:after {
					background: #009788;
					color: #009788;
				}
			}
			.stat-detail-info {
				i {
					color: #009788;
				}
			}
			>h2 {
				background: #212121;
			}
		}
	}
	.progress-bar {
		background: #009788;
	}
	table.dataTable.dtr-inline.collapsed {
		>tbody {
			>tr[role="row"] {
				>td {
					&:first-child {
						&:before {
							background: #009788;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #009788;
						}
					}
				}
			}
			>tr.parent {
				>td {
					&:first-child {
						&:before {
							background: #212121;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #212121;
						}
					}
				}
			}
		}
	}
	input[type=radio] {
		&:checked {
			&:before {
				background: #009788;
			}
		}
	}
	.navbar-default.sidebar {
		ul {
			li {
				a.active {
					background-color: #171717;
					color: #fff;
				}
			}
		}
		a {
			&:hover {
				background-color: #171717;
				color: #fff;
			}
			&:focus {
				background-color: #171717;
				color: #fff;
			}
		}
	}
	.sidebar {
		background: #212121;
		color: #bcb7b2;
		a.active {
			i {
				color: #e9e4e0;
			}
		}
	}
	.vendor-cover-wrap {
		.cover-pic-button {
			button {
				color: #fff;
				background-color: #009788;
				border-color: #009788;
			}
		}
		.vendor-profile-pic-wraper {
			.profile-pic-btn {
				color: #fff;
				background-color: #009788;
				border-color: #009788;
			}
		}
	}
	.woocommerce-exporter-wrapper {
		.button {
			color: #fff;
			background-color: #009788;
			border-color: #009788;
		}
		.wc-progress-steps {
			li.active {
				border-color: #009788 !important;
				color: #009788 !important;
				&::before {
					border-color: #009788 !important;
				}
			}
		}
	}
	.woocommerce-importer-wrapper {
		.button {
			color: #fff;
			background-color: #009788;
			border-color: #009788;
		}
		.wc-progress-steps {
			li.active {
				border-color: #009788 !important;
				color: #009788 !important;
				&::before {
					border-color: #009788 !important;
				}
			}
		}
	}
	.woocommerce-progress-form-wrapper {
		.button {
			color: #fff;
			background-color: #009788;
			border-color: #009788;
		}
		.wc-progress-steps {
			li.active {
				border-color: #009788 !important;
				color: #009788 !important;
				&::before {
					border-color: #009788 !important;
				}
			}
		}
	}
	.btn.btn-default {
		color: #fff;
		background-color: #00796a;
		border-color: #00796a;
	}
	.btn.btn-secondary {
		color: #fff;
		background-color: #212121;
		border-color: #212121;
	}
	.pagination {
		li.active {
			a {
				background: #009788;
				border-color: #009788;
			}
		}
	}
	a {
		color: #00796a;
		&:hover {
			color: #212121;
		}
	}
	.media-body {
		a {
			color: #00796a;
			&:hover {
				color: #212121;
			}
		}
	}
	.sidebar.navbar-default {
		ul {
			a {
				&:hover {
					i {
						color: #009788;
						color: #009788;
					}
				}
			}
			a.active {
				i {
					color: #009788;
					color: #009788;
				}
			}
		}
	}
	.navbar-top-links {
		li.notification-link {
			a {
				&:hover {
					color: #009788;
					i {
						color: #009788;
					}
				}
			}
		}
		li {
			a {
				&:hover {
					color: #009788;
				}
			}
		}
	}
	ul.nav {
		.login-user {
			a {
				&:hover {
					i {
						color: #009788;
					}
				}
			}
			.dropdown-menu.dropdown-user {
				a {
					&:hover {
						color: #009788;
					}
				}
			}
		}
	}
	.transaction-list {
		color: #009788;
	}
	.product-import.wcmp_displaybox2m {
		h3 {
			color: #009788;
		}
	}
	.wcmp_displaybox2 {
		h3 {
			color: #009788;
		}
	}
	input[type=checkbox] {
		&:checked {
			&:before {
				color: #009788;
			}
		}
	}
	.wcmp_vendor_transaction_details {
		color: #fff;
		.panel-body {
			background: #009788 !important;
		}
		.panel-footer {
			background: #00796a !important;
			a {
				color: #fff;
			}
		}
	}
	.top-user-nav {
		>li {
			a.dropdown-toggle {
				background: #212121;
			}
		}
	}
	.current-stat-report {
		color: #00796a;
		background: rgba(0, 121, 106, 0.2);
	}
	.product-tab-nav-holder {
		ul {
			li.active {
				a {
					border-top-color: #009788;
					&:hover {
						border-top-color: #009788;
					}
					&:focus {
						border-top-color: #009788;
					}
				}
			}
		}
	}
	.primary-color {
		color: #009788;
	}
	.wcmp-vendor-ledger-report-row {
		.bg-ledger {
			background: #009788;
		}
	}
}
.wcmp-color-scheme-old_west {
	.navbar {
		.topbar-left {
			background: #c7a589;
		}
	}
	.navbar-default {
		.navbar-toggle {
			.icon-bar {
				background: #c7a589;
			}
		}
	}
	.staticstics-panel-wrap {
		.panel-body {
			.compare-stat-info {
				&:after {
					background: #c7a589;
					color: #c7a589;
				}
			}
			.stat-detail-info {
				i {
					color: #c7a589;
				}
			}
			>h2 {
				background: #59524c;
			}
		}
	}
	.progress-bar {
		background: #c7a589;
	}
	table.dataTable.dtr-inline.collapsed {
		>tbody {
			>tr[role="row"] {
				>td {
					&:first-child {
						&:before {
							background: #c7a589;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #c7a589;
						}
					}
				}
			}
			>tr.parent {
				>td {
					&:first-child {
						&:before {
							background: #59524c;
						}
					}
				}
				>th {
					&:first-child {
						&:before {
							background: #59524c;
						}
					}
				}
			}
		}
	}
	input[type=radio] {
		&:checked {
			&:before {
				background: #c7a589;
			}
		}
	}
	.navbar-default.sidebar {
		ul {
			li {
				a.active {
					background-color: #46403c;
					color: #fff;
				}
			}
		}
		a {
			&:hover {
				background-color: #46403c;
				color: #fff;
			}
			&:focus {
				background-color: #46403c;
				color: #fff;
			}
		}
	}
	.sidebar {
		background: #59524c;
		color: #bcb7b2;
		a.active {
			i {
				color: #e9e4e0;
			}
		}
	}
	.vendor-cover-wrap {
		.cover-pic-button {
			button {
				color: #fff;
				background-color: #c7a589;
				border-color: #c7a589;
			}
		}
		.vendor-profile-pic-wraper {
			.profile-pic-btn {
				color: #fff;
				background-color: #c7a589;
				border-color: #c7a589;
			}
		}
	}
	.woocommerce-exporter-wrapper {
		.button {
			color: #fff;
			background-color: #c7a589;
			border-color: #c7a589;
		}
		.wc-progress-steps {
			li.active {
				border-color: #c7a589 !important;
				color: #c7a589 !important;
				&::before {
					border-color: #c7a589 !important;
				}
			}
		}
	}
	.woocommerce-importer-wrapper {
		.button {
			color: #fff;
			background-color: #c7a589;
			border-color: #c7a589;
		}
		.wc-progress-steps {
			li.active {
				border-color: #c7a589 !important;
				color: #c7a589 !important;
				&::before {
					border-color: #c7a589 !important;
				}
			}
		}
	}
	.woocommerce-progress-form-wrapper {
		.button {
			color: #fff;
			background-color: #c7a589;
			border-color: #c7a589;
		}
		.wc-progress-steps {
			li.active {
				border-color: #c7a589 !important;
				color: #c7a589 !important;
				&::before {
					border-color: #c7a589 !important;
				}
			}
		}
	}
	.btn.btn-default {
		color: #fff;
		background-color: #ad8162;
		border-color: #ad8162;
	}
	.btn.btn-secondary {
		color: #fff;
		background-color: #59524c;
		border-color: #59524c;
	}
	.pagination {
		li.active {
			a {
				background: #c7a589;
				border-color: #c7a589;
			}
		}
	}
	a {
		color: #9b6b47;
		&:hover {
			color: #59524c;
		}
	}
	.media-body {
		a {
			color: #9b6b47;
			&:hover {
				color: #59524c;
			}
		}
	}
	.sidebar.navbar-default {
		ul {
			a {
				&:hover {
					i {
						color: #c7a589;
						color: #c7a589;
					}
				}
			}
			a.active {
				i {
					color: #c7a589;
					color: #c7a589;
				}
			}
		}
	}
	.navbar-top-links {
		li.notification-link {
			a {
				&:hover {
					color: #c7a589;
					i {
						color: #c7a589;
					}
				}
			}
		}
		li {
			a {
				&:hover {
					color: #c7a589;
				}
			}
		}
	}
	ul.nav {
		.login-user {
			a {
				&:hover {
					i {
						color: #c7a589;
					}
				}
			}
			.dropdown-menu.dropdown-user {
				a {
					&:hover {
						color: #c7a589;
					}
				}
			}
		}
	}
	.transaction-list {
		color: #c7a589;
	}
	.product-import.wcmp_displaybox2m {
		h3 {
			color: #c7a589;
		}
	}
	.wcmp_displaybox2 {
		h3 {
			color: #c7a589;
		}
	}
	input[type=checkbox] {
		&:checked {
			&:before {
				color: #c7a589;
			}
		}
	}
	.wcmp_vendor_transaction_details {
		color: #000;
		.panel-body {
			background: #c7a589 !important;
		}
		.panel-footer {
			background: #ad8162 !important;
			a {
				color: #fff;
			}
		}
	}
	.top-user-nav {
		>li {
			a.dropdown-toggle {
				background: #59524c;
			}
		}
	}
	.current-stat-report {
		color: #9b6b47;
		background: rgba(199, 165, 137, 0.3);
	}
	.product-tab-nav-holder {
		ul {
			li.active {
				a {
					border-top-color: #c7a589;
					&:hover {
						border-top-color: #c7a589;
					}
					&:focus {
						border-top-color: #c7a589;
					}
				}
			}
		}
	}
	.primary-color {
		color: #c7a589;
	}
	.wcmp-vendor-ledger-report-row {
		.bg-ledger {
			background: #c7a589;
		}
	}
}
.wcmp-color-scheme-wild_watermelon {
	.navbar {
		.topbar-left {
			background: #fd5668;
		}
	}
	.navbar-default {
		.navbar-toggle {
			.icon-bar {
				background: #fd5668;
			}
		}
	}
	.staticstics-panel-wrap {
		.panel-body {
			.compare-stat-info {
				&:after {
					background: #fd5668;
					color: #fd5668;
				}
			}
			.stat-detail-info {
				i {
					color: #fd5668;
				}
			}
			>h2 {
				background: #181617;
			}
		}
	}
	.progress-bar {
		background: #fd5668;
	}
	input[type=radio] {
		&:checked {
			&:before {
				background: #fd5668;
			}
		}
	}
	.navbar-default.sidebar {
		ul {
			li {
				a.active {
					background-color: #353130;
					color: #fff;
				}
			}
		}
		a {
			&:hover {
				background-color: #353130;
				color: #fff;
			}
			&:focus {
				background-color: #353130;
				color: #fff;
			}
		}
	}
	.sidebar {
		background: #181617;
		color: #bcb7b2;
		a.active {
			i {
				color: #e9e4e0;
			}
		}
	}
	.vendor-cover-wrap {
		.cover-pic-button {
			button {
				color: #fff;
				background-color: #fd5668;
				border-color: #fd5668;
			}
		}
		.vendor-profile-pic-wraper {
			.profile-pic-btn {
				color: #fff;
				background-color: #fd5668;
				border-color: #fd5668;
			}
		}
	}
	.woocommerce-exporter-wrapper {
		.button {
			color: #fff;
			background-color: #fd5668;
			border-color: #fd5668;
		}
		.wc-progress-steps {
			li.active {
				border-color: #fd5668 !important;
				color: #fd5668 !important;
				&::before {
					border-color: #fd5668 !important;
				}
			}
		}
	}
	.woocommerce-importer-wrapper {
		.button {
			color: #fff;
			background-color: #fd5668;
			border-color: #fd5668;
		}
		.wc-progress-steps {
			li.active {
				border-color: #fd5668 !important;
				color: #fd5668 !important;
				&::before {
					border-color: #fd5668 !important;
				}
			}
		}
	}
	.woocommerce-progress-form-wrapper {
		.button {
			color: #fff;
			background-color: #fd5668;
			border-color: #fd5668;
		}
		.wc-progress-steps {
			li.active {
				border-color: #fd5668 !important;
				color: #fd5668 !important;
				&::before {
					border-color: #fd5668 !important;
				}
			}
		}
	}
	.btn.btn-default {
		color: #fff;
		background-color: #fb3f4e;
		border-color: #fb3f4e;
	}
	.btn.btn-secondary {
		color: #fff;
		background-color: #181617;
		border-color: #181617;
	}
	.pagination {
		li.active {
			a {
				background: #fd5668;
				border-color: #fd5668;
			}
		}
	}
	a {
		color: #fb3f4e;
		&:hover {
			color: #181617;
		}
	}
	.media-body {
		a {
			color: #fb3f4e;
			&:hover {
				color: #181617;
			}
		}
	}
	.sidebar.navbar-default {
		ul {
			a {
				&:hover {
					i {
						color: #fd5668;
						color: #fd5668;
					}
				}
			}
			a.active {
				i {
					color: #fd5668;
					color: #fd5668;
				}
			}
		}
	}
	.navbar-top-links {
		li.notification-link {
			a {
				&:hover {
					color: #fd5668;
					i {
						color: #fd5668;
					}
				}
			}
		}
		li {
			a {
				&:hover {
					color: #fd5668;
				}
			}
		}
	}
	ul.nav {
		.login-user {
			a {
				&:hover {
					i {
						color: #fd5668;
					}
				}
			}
			.dropdown-menu.dropdown-user {
				a {
					&:hover {
						color: #fd5668;
					}
				}
			}
		}
	}
	.transaction-list {
		color: #fd5668;
	}
	.product-import.wcmp_displaybox2m {
		h3 {
			color: #fd5668;
		}
	}
	.wcmp_displaybox2 {
		h3 {
			color: #fd5668;
		}
	}
	input[type=checkbox] {
		&:checked {
			&:before {
				color: #fd5668;
			}
		}
	}
	.wcmp_vendor_transaction_details {
		color: #fff;
		.panel-body {
			background: #fd5668 !important;
		}
		.panel-footer {
			background: #fb3f4e !important;
			a {
				color: #fff;
			}
		}
	}
	.top-user-nav {
		>li {
			a.dropdown-toggle {
				background: #181617;
			}
		}
	}
	.current-stat-report {
		color: #fb3f4e;
		background: rgba(251, 63, 78, 0.2);
	}
	.product-tab-nav-holder {
		ul {
			li.active {
				a {
					border-top-color: #fd5668;
					&:hover {
						border-top-color: #fd5668;
					}
					&:focus {
						border-top-color: #fd5668;
					}
				}
			}
		}
	}
	.primary-color {
		color: #fd5668;
	}
	.wcmp-vendor-ledger-report-row {
		.bg-ledger {
			background: #fd5668;
		}
	}
}
.dashboard-top-content {
	background-color: #f7f8fa;
	h3 {
		margin: 0;
	}
}
table.table.product_sold_last_week {
	tbody {
		text-align: left;
	}
	.wcmp_no-data {
		text-align: center;
	}
	.product_sold_last_week_name_class {
		img {
			margin-right: 12px;
			width: 26px;
			height: auto;
			max-height: 26px;
		}
	}
}
#widget_product_sales_report.wcmp-widget-dt.table.dataTable {
	tbody {
		td {
			border-top: 1px solid #d3dbe2;
		}
	}
}
#widget_vendor_pending_shipping.wcmp-widget-dt.table.dataTable {
	tbody {
		td {
			border-top: 1px solid #d3dbe2;
		}
	}
}
.wcmp_vendor_product_sales_report.panel.panel-default.pannel-outer-heading {
	.panel-body {
		background: transparent;
	}
}
.wcmp_vendor_pending_shipping.panel.panel-default.pannel-outer-heading {
	.panel-body {
		background: transparent;
	}
}
td {
	&:focus {
		outline: none;
	}
}
.panel.panel-default.wcmp_vendor_stats_reports {
	margin-top: 0;
}
.key-perfomence-indicator {
	width: 354px;
	max-width: 100%;
	+ {
		.col-md-8 {
			width: calc(100% - 354px);
		}
	}
}
.vendor_visitors_map {
	.map-nav {
		box-shadow: 0 0 6px 1px rgba(0, 0, 0, 0.28);
		background: #fff;
		position: absolute;
		right: 10px;
		bottom: 10px;
		overflow: hidden;
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
		border-radius: 3px;
		line-height: 10px;
		text-align: center;
	}
	.jqvmap-zoomin {
		color: #333332;
		background: #fff;
		position: relative;
		top: 0;
		left: 0;
		width: 25px;
		height: 25px;
		line-height: 18px;
		font-size: 16px;
		&:after {
			position: absolute;
			content: '';
			width: calc(100% - 8px);
			height: 1px;
			background: #e6e6e6;
			bottom: -1px;
			left: 0;
			right: 0;
			margin: auto;
			z-index: 1;
		}
	}
	.jqvmap-zoomout {
		color: #333332;
		background: #fff;
		position: relative;
		top: 0;
		left: 0;
		width: 25px;
		height: 25px;
		line-height: 18px;
		font-size: 16px;
	}
}
#visitor_data_stats.table {
	margin-top: 20px;
	thead {
		th {
			font-size: 11px;
		}
	}
	>tbody {
		>tr {
			>td {
				padding: 6px 7px;
				font-size: 12px;
				&:first-of-type {
					border: 0;
				}
			}
			>td.region {
				color: #fff;
			}
			>td.no_data {
				text-align: center;
			}
		}
	}
}
.vendor-products-qna-filters {
	.form-group {
		max-width: 330px;
		vertical-align: top;
		min-width: 200px;
	}
	.select2-container--default.select2-container--focus {
		.select2-selection--multiple {
			border-color: #c5c5c5;
		}
	}
	.select2-container {
		.select2-selection.select2-selection--multiple {
			min-height: 34px;
			.select2-selection__rendered {
				.select2-selection__choice {
					margin-top: 5px;
				}
			}
		}
		.select2-search--inline {
			margin-top: 7px;
		}
	}
	#show_qna_by_products_btn {
		margin-left: 6px;
	}
	li {
		+ {
			li.select2-search.select2-search--inline {
				input.select2-search__field {
					width: 0.75em !important;
				}
			}
		}
	}
}
#vendor_products_qna_table {
	span.unanswered.label-default {
		font-size: 12px;
		background-color: #f8dda7;
		color: #94660c;
	}
	span.answered.label-success {
		font-size: 12px;
		background-color: #c6e1c6;
		color: #5b841b;
	}
}
#donutchart {
	svg {
		rect {
			+ {
				text {
					font-size: 20px;
				}
			}
		}
	}
}
.dash-widget-dt {
	div.dataTables_wrapper {
		div.dataTables_paginate {
			text-align: left;
			ul.pagination {
				margin: 15px 0 15px 20px;
			}
		}
	}
}
.wcmp-widget-dt.table.dataTable {
	margin: 0 !important;
	tbody {
		td {
			border-top: none;
		}
	}
}
.dt-wrapper {
	overflow: auto;
	table {
		&:not(.wcmp-widget-dt) {
			min-width: 850px;
			width: 100% !important;
		}
	}
}
.wcmp_billing_form {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
	.payment-gateway {
		h4 {
			margin-top: 50px;
		}
		.form-group {
			&:last-of-type {
				margin-bottom: 0;
			}
		}
	}
}
.all-products-wrapper {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.coupons {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.vendor-report {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.vendor-orders {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.vendor-withdrawal {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.transaction-details {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
	#vendor_transactions_date_filter {
		margin: 0 0 -33px 0;
	}
}
.add-staff {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.vendor-tools {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.vendor-knowledgebase {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
.wcmp_profile_form {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
	#vendor-profile-img {
		width: 130px;
		padding: 3px;
		border: solid 1px #ccc;
		margin-bottom: 8px;
	}
}
.wcmp_shipping_form {
	.panel.panel-default {
		&:first-of-type {
			margin-top: 0;
		}
	}
}
form[name="wcmp_vendor_dashboard_orders"] {
	.form-group {
		margin-right: 8px;
	}
}
#vendor_transactions_date_filter {
	.form-group {
		margin-right: 8px;
	}
}
.checkbox-holder {
	position: relative;
	display: inline-block;
	cursor: pointer;
	vertical-align: middle;
	.wcmp-font {
		font-size: 20px;
		vertical-align: middle;
		color: #c5c5c5;
		position: absolute;
		left: 0;
		top: 0;
	}
	input[type="checkbox"] {
		width: 22px;
		height: 22px;
		opacity: 0;
		z-index: 1;
		position: relative;
		margin: 0 !important;
		vertical-align: middle !important;
		cursor: pointer;
		&:checked {
			background: #fff;
			+ {
				.ico-uncheckbox-icon {
					background: #fff;
					&:before {
						content: '\e90b';
					}
				}
			}
		}
	}
}
input[type=radio] {
	border: 2px solid #cecdcd;
	background: #fff;
	color: #c5c5c5;
	clear: none;
	cursor: pointer;
	display: inline-block;
	line-height: 0;
	height: 20px;
	margin: 0;
	outline: 0;
	padding: 0 !important;
	text-align: center;
	vertical-align: middle;
	width: 20px;
	min-width: 20px;
	-webkit-appearance: none;
	transition: .05s border-color ease-in-out;
	border-radius: 3px;
	border-radius: 50%;
	line-height: 10px;
	margin: 3px 4px 4px 0;
	&:focus {
		border-color: #cecdcd;
		box-shadow: none;
		outline: none;
	}
	&:checked {
		&:before {
			float: left;
			display: inline-block;
			vertical-align: middle;
			width: 20px;
			height: 20px;
			font: 400 20px/1 'wcmp' !important;
			speak: none;
			-webkit-font-smoothing: antialiased;
			-moz-osx-font-smoothing: grayscale;
			content: "";
			border-radius: 50%;
			font-size: 24px;
			width: 12px;
			height: 12px;
			margin: 2px;
			line-height: 16px;
		}
		border-color: #66afe9;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px rgba(102, 175, 233, 0.6);
	}
}
input[type=checkbox] {
	border: 2px solid #cecdcd;
	background: #fff;
	color: #c5c5c5;
	clear: none;
	cursor: pointer;
	display: inline-block;
	line-height: 0;
	height: 20px;
	margin: 0;
	outline: 0;
	padding: 0 !important;
	text-align: center;
	vertical-align: middle;
	width: 20px;
	min-width: 20px;
	-webkit-appearance: none;
	transition: .05s border-color ease-in-out;
	border-radius: 3px;
	&:focus {
		border-color: #cecdcd;
		box-shadow: none;
		outline: none;
	}
	&:checked {
		&:before {
			float: left;
			display: inline-block;
			vertical-align: middle;
			width: 20px;
			height: 20px;
			font: 400 20px/1 'wcmp' !important;
			speak: none;
			-webkit-font-smoothing: antialiased;
			-moz-osx-font-smoothing: grayscale;
			content: '\e90b';
			margin: -2px 0 0 -2px;
		}
	}
}
.pro_ele_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.pro_head_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.pro_block_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.non_stock_ele_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.non_virtual_ele_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.downloadable_ele_hide {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.vendor_hidden {
	+ {
		.wcmp-font {
			display: none !important;
		}
	}
	display: none !important;
}
.slug-inp {
	display: inline-block;
	width: 150px;
	max-width: 100%;
}
.upload_button.wcmp_black_btn {
	display: block !important;
}
.remove_button.wcmp_black_btn {
	display: block !important;
}
.wcmp_media_block {
	.dc-wp-fields-uploader {
		display: block;
		img {
			border-radius: 0;
		}
	}
	.button-group {
		.btn {
			width: 100%;
			display: block;
			border-radius: 0;
		}
	}
	.facebook {
		color: #4867aa;
	}
	.twitter {
		color: #1da1f2;
	}
	.linkedin {
		color: #007bb6;
	}
	.google-plus {
		color: #dd4c40;
	}
	.youtube {
		color: #ff0000;
	}
	.instagram {
		color: #8536ec;
	}
}
.panel.panel-default.vendor-cover-panel {
	margin-bottom: 55px;
}
.vendor-cover-wrap {
	position: relative;
	#vendor-cover-img {
		min-height: 200px;
	}
	img {
		height: auto;
		width: 100%;
	}
	.vendor-profile-pic-wraper {
		width: 100px;
		position: absolute;
		bottom: -37px;
		left: 20px;
		overflow: hidden;
		padding-bottom: 37px;
		.profile-pic-btn {
			position: absolute;
			bottom: 0;
			right: 0;
			width: 100%;
			background: #3f85b9;
			padding: 5px;
			color: #fff;
			transition: all 0.3s;
			text-align: center;
			button {
				background: transparent;
				border: none;
				padding: 0;
				height: 27px;
				span {
					font-size: 17px;
				}
			}
			&:hover {
				background: #202627;
			}
		}
	}
	.cover-pic-button {
		position: absolute;
		bottom: 30px;
		right: 125px;
		button {
			border: none;
			background: #3f85b9;
			padding: 9px 15px;
			color: #fff;
			transition: all 0.3s;
			&:hover {
				background: #202627;
			}
		}
	}
}
.wcmp_template_list {
	li {
		position: relative;
		margin: 0 4% 20px 0;
		width: 48%;
		float: left;
		vertical-align: top;
		&:nth-child(2n+2) {
			margin-right: 0;
		}
		label {
			cursor: pointer;
			margin: 0;
			i.dashicons {
				position: absolute;
				background: #151715;
				color: #fff;
				padding: 8px;
				top: 50%;
				width: 35px;
				left: 50%;
				height: 35px;
				z-index: 1;
				transform: translateX(-50%) translateY(-50%);
				opacity: 0;
			}
		}
		input[type="radio"] {
			visibility: hidden;
			display: none;
			&:checked {
				+ {
					i.dashicons {
						background: #fff;
						opacity: 1;
						+ {
							.template-overlay {
								opacity: 1;
								background: rgba(0, 0, 0, 0.5);
							}
						}
					}
				}
			}
		}
		.template-overlay {
			position: absolute;
			top: 0;
			left: 0;
			right: 0;
			bottom: 0;
			background: rgba(0, 0, 0, 0.3);
			opacity: 0;
			transition: all 0.3s;
		}
		&:hover {
			.template-overlay {
				opacity: 1;
			}
			i.dashicons {
				opacity: 1;
			}
		}
	}
}
.shipping_table {
	margin-bottom: 25px;
	tr {
		>td {
			padding: 20px;
		}
		td {
			h2 {
				margin: 0;
			}
			label {
				margin: 0;
				color: #4d4d4d;
				font-size: 15px;
				font-weight: 700;
				padding: 0;
			}
			input {
				margin: 0;
			}
			padding: 20px;
			input[type="text"] {
				border: 1px solid #dedede;
				box-shadow: none;
				color: #7e7e7e;
				font-size: 14px;
				height: 28px;
				line-height: 43px;
				margin: 0 4% 0;
				padding: 3px 5px;
				width: 92%;
			}
			input[type="number"] {
				border: 1px solid #dedede;
				box-shadow: none;
				color: #7e7e7e;
				font-size: 14px;
				height: 28px;
				line-height: 43px;
				margin: 0 4% 0;
				padding: 3px 5px;
				width: 92%;
			}
			input[type="submit"] {
				-moz-border-bottom-colors: none;
				-moz-border-left-colors: none;
				-moz-border-right-colors: none;
				-moz-border-top-colors: none;
				background: rgba(0, 0, 0, 0) -moz-linear-gradient(center top, #f74b33 0%, #e1442e 50%, #cf3f2b 100%) repeat scroll 0 0;
				border-color: #ff8877 -moz-use-text-color #9f291a;
				border-image: none;
				border-radius: 4px;
				border-style: solid none;
				border-width: 2px 0;
				color: #fff;
				cursor: pointer;
				float: right;
				font-size: 15px;
				font-weight: bold;
				margin: 3px 4%;
				padding: 9px 15px;
			}
		}
		th {
			padding: 20px;
		}
	}
	h2 {
		font-size: 20px;
	}
}
.hints {
	padding: 21px 10% 15px;
	overflow: hidden;
	background: #f6f6f6 none repeat scroll 0 0;
	border: 1px solid #e5e6e5;
	border-radius: 3px;
	color: #3a3a39;
	font-size: 11px;
	padding: 2% 5%;
	position: relative;
	margin-top: 10px;
	&:after {
		content: '';
		border: none;
		background: none;
		border-bottom: 7px solid #e5e6e5;
		border-left: 7px solid transparent;
		border-right: 7px solid transparent;
		height: 0;
		left: 5px;
		padding: 0;
		position: absolute;
		top: -8px;
		width: 0;
	}
}
.vendor_non_configuration_msg {
	margin: 28px;
	color: #fc482f;
}
table.shipping_table {
	td {
		border: 1px solid #d1d7df !important;
	}
}
.frontend_product_manager_product_types {
	background: #fff;
	padding: 20px;
	.form-group {
		display: inline-block;
		vertical-align: top;
		margin: 0;
		#product_type {
			vertical-align: middle;
			min-width: 120px;
		}
		label {
			vertical-align: middle;
			display: inline-block;
			margin: 7px 0 0;
			padding: 0;
		}
	}
	.form-group.is_virtual_wrapper {
		margin-right: 15px;
		margin-left: 15px;
	}
	.form-group.product_type_wrapper {
		margin: 0;
		label {
			margin-top: 6px;
		}
	}
	[class*="col-sm-"] {
		width: auto !important;
		display: inline-block;
		vertical-align: middle;
	}
	.wcmp-no-product-type-notice {
		float: right;
		margin-top: 9px;
	}
	.product_type.pro_title {
		padding: 0;
	}
}
#mceu_26 {
	border-right-width: 1px !important;
}
#product_manager_form {
	.frontend_product_manager_product_types {
		.form-group {
			label {
				margin: 10px 0 0;
			}
		}
	}
}
.default_attributes_holder {
	.dft_sel_wrap {
		select {
			margin: 0 6% 10px 0;
			&:nth-child(even) {
				margin-right: 0;
			}
			&:nth-last-of-type(2) {
				margin-bottom: 0;
			}
			&:last-of-type {
				margin-bottom: 0;
			}
		}
	}
	select.regular-select {
		width: 47%;
		display: inline-block;
	}
}
.add-product-backend {
	padding: 20px;
	border-top: 1px solid #d3dbe2;
	background: #fff;
	font-size: 16px;
	p {
		margin: 0;
		i {
			font-size: 20px;
			vertical-align: middle;
			margin: 0 0 4px 9px;
			display: inline-block;
		}
	}
}
.woocommerce-exporter-wrapper {
	.wc-progress-steps {
		li.active {
			border-color: #3f85b9 !important;
			color: #3f85b9 !important;
			&::before {
				border-color: #3f85b9 !important;
			}
		}
		li.done {
			border-color: #fff !important;
			color: #fff !important;
			&::before {
				border-color: #fff !important;
				background: #fff !important;
			}
		}
	}
	.button {
		&:active {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:focus {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:hover {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
	}
}
.woocommerce-importer-wrapper {
	.wc-progress-steps {
		li.active {
			border-color: #3f85b9 !important;
			color: #3f85b9 !important;
			&::before {
				border-color: #3f85b9 !important;
			}
		}
		li.done {
			border-color: #fff !important;
			color: #fff !important;
			&::before {
				border-color: #fff !important;
				background: #fff !important;
			}
		}
	}
	.button {
		&:active {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:focus {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:hover {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
	}
}
.woocommerce-progress-form-wrapper {
	.wc-progress-steps {
		li.active {
			border-color: #3f85b9 !important;
			color: #3f85b9 !important;
			&::before {
				border-color: #3f85b9 !important;
			}
		}
		li.done {
			border-color: #fff !important;
			color: #fff !important;
			&::before {
				border-color: #fff !important;
				background: #fff !important;
			}
		}
	}
	.button {
		&:active {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:focus {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
		&:hover {
			background: #3f85b9 !important;
			box-shadow: none !important;
			color: #fff !important;
		}
	}
}
.product-import {
	.woocommerce.wrap {
		display: block;
		margin: 30px auto 0;
		max-width: 100%;
		h1 {
			display: none;
		}
		table {
			tr {
				background: transparent;
				th {
					border: none;
				}
				td {
					border: none;
				}
			}
		}
	}
}
.product-export {
	.woocommerce.wrap {
		display: block;
		margin: 30px auto 0;
		max-width: 100%;
		width: 100%;
		max-width: 100%;
		margin-top: 0;
		margin-bottom: 0;
		h1 {
			display: none;
		}
		table {
			tr {
				background: transparent;
				th {
					border: none;
				}
				td {
					border: none;
				}
			}
		}
	}
	.woocommerce-exporter-wrapper {
		width: 100%;
		max-width: 100%;
		margin-top: 0;
		margin-bottom: 0;
	}
}
.woocommerce-importer-options {
	input {
		+ {
			br {
				display: none;
			}
		}
	}
}
.woocommerce-exporter {
	h2 {
		margin: 0 0 1px !important;
		color: #252525 !important;
		font-size: 17px !important;
		line-height: 22px !important;
		+ {
			p {
				margin: 0 0 15px !important;
				font-size: 13px !important;
			}
		}
	}
	.woocommerce-exporter-options {
		td {
			padding: 0 0 15px 0;
			.select2-container {
				width: 300px !important;
				max-width: 100% !important;
			}
		}
	}
}
.wc_bookings_calendar {
	tr {
		th {
			padding-bottom: 10px;
		}
	}
}
.all-booking {
	.wcmp_tab.ui-tabs {
		padding: 0;
		border: none;
		label {
			font-weight: normal;
		}
		.dataTables_filter {
			text-align: right;
			.form-control {
				margin-left: 0.5em;
			}
		}
		.wcmp_booking_tbl {
			margin-top: 5px;
			tbody {
				strong {
					color: #333b3d;
					&:hover {
						color: #3f85b9;
					}
				}
				.wcmp_table_action {
					color: #333b3d;
					&:hover {
						color: #3f85b9;
					}
				}
			}
		}
	}
}
.booking-details {
	.booking-customer-details {
		tbody {
			border: 1px solid #ddd;
		}
		th {
			border-bottom-color: #ddd;
			background: initial;
			border-right: 1px solid #ddd;
			th {
				background: initial;
			}
		}
	}
}
#mceu_64-head {
	#mceu_64-t0 {
		display: none !important;
	}
	#mceu_64-t2 {
		display: none !important;
	}
	#mceu_64-t1 {
		display: block !important;
	}
}
#mceu_64-body {
	#mceu_65 {
		display: none !important;
	}
	#mceu_74 {
		display: none !important;
	}
	#mceu_72 {
		display: none !important;
	}
}
.mce-container.mce-panel.mce-foot {
	button {
		color: #fff;
	}
}
.mce-container {
	iframe {
		min-height: 100px !important;
	}
}
.select2-container--default {
	.select2-search--inline {
		width: 100%;
	}
	li {
		+ {
			.select2-search--inline {
				width: auto;
			}
		}
	}
}
#wc_bookings_field_duration {
	display: inline-block;
	vertical-align: middle;
}
.wc_bookings_field_start_date {
	legend {
		.label {
			padding: 0;
			margin-top: 26px;
			display: inline-block;
		}
	}
}
.product-filter-actions {
	.alignleft.actions {
		button {
			border-radius: 4px;
			&:not(:last-of-type) {
				margin-right: 10px;
			}
		}
	}
}
.product-list-filter-wrap {
	.form-group {
		margin-bottom: 7px;
	}
}
#product_table {
	tbody {
		.select_product {
			text-align: center;
			vertical-align: middle;
		}
	}
	th.actions {
		min-width: 110px !important;
	}
	td.actions {
		min-width: 110px !important;
		.col-actions {
			white-space: nowrap;
		}
	}
}
.product-title-wrap {
	overflow: hidden;
}
.select-product-cat-wrapper {
	.cat-intro {
		img {
			margin: 30px 0;
		}
		.serach-product-cat-wrapper {
			margin-bottom: 40px;
			h2 {
				color: #333b3d;
			}
			form {
				margin: 15px 0 45px;
				position: relative;
				.form-control {
					max-width: 100%;
					width: 395px;
				}
				&:after {
					content: '...';
					position: absolute;
					bottom: -39px;
					font-size: 41px;
					left: 0;
					right: 0;
					margin: auto;
					color: rgba(110, 114, 115, 0.7);
					pointer-events: none;
				}
			}
		}
		.search-result-holder {
			.search-result-clm {
				border-bottom: 1px solid #d3dbe2;
				padding: 20px;
				overflow: hidden;
				img {
					margin: 0 25px 0 0;
					float: left;
					border: 1px solid #d3dbe2;
					padding: 10px;
					max-height: 98px;
					width: auto;
					max-width: 130px;
				}
				.result-content {
					width: calc(100% - 312px);
					display: inline-block;
					vertical-align: middle;
				}
				a {
					margin-left: 30px;
				}
			}
		}
	}
	.select-cat-step-wrapper {
		.wcmp-categories-level-panel {
			background: #fff url("../../images/icon-bg.png") repeat top;
			border: 1px solid #d3dbe2;
			padding: 20px;
			overflow: hidden;
		}
		.cat-list-holder {
			position: relative;
			height: 367px;
			overflow: hidden;
			background: transparent !important;
		}
		.cat-column-scroller {
			position: absolute;
			width: 50px;
			background: #e1e6ec;
			color: #3f85b9;
			text-align: center;
			cursor: pointer;
			z-index: 3;
			font-size: 28px;
			top: 0;
			bottom: 0;
			i {
				position: absolute;
				top: 50%;
				transform: translateY(-50%);
				left: 0;
				right: 0;
				margin: auto;
			}
		}
		.cat-column-scroller.cat-left-scroller {
			left: 0;
		}
		.cat-column-scroller.cat-right-scroller {
			right: 0;
		}
		.has-scroller.wcmp-categories-level-panel {
			padding-left: 60px;
			padding-right: 60px;
			position: relative;
		}
		.cat-column-wrapper {
			overflow: hidden;
			position: relative;
			height: 100%;
			transition: all 0.3s;
			.cat-column {
				&:nth-last-of-type(3) {
					border-right: 1px solid #d3dbe2;
				}
				&:not(:first-child) {
					margin-left: -1px;
				}
			}
		}
		.select-category-graphic {
			float: left;
			width: 66.67%;
			text-align: center;
			position: absolute;
			top: 50%;
			transform: translateY(-50%);
			right: 0;
			img {
				margin: 0 0 15px;
			}
			h1 {
				font-weight: 300;
				color: #4e5a5d;
			}
			&:after {
				position: absolute;
				content: '';
				width: 471px;
				height: 261px;
				box-shadow: 1px 1px 176px white;
				left: 0;
				right: 0;
				margin: auto;
				top: -27px;
				bottom: 0;
				z-index: -1;
				background: rgba(255, 255, 255, 0.4);
				border-radius: 240px 240px 25px 25px;
			}
		}
		.cat-column {
			width: 33.33%;
			float: left;
			border: 1px solid #d3dbe2;
			height: 100%;
			overflow: auto;
			background: #fff;
			li {
				position: relative;
				&:after {
					content: '';
					position: absolute;
					background: #d3dbe2;
					width: calc(100% - 60px);
					height: 1px;
					margin: auto;
					left: 0;
					right: 0;
					bottom: 0;
				}
				&:last-of-type {
					&:after {
						display: none;
					}
				}
				a {
					color: #4e5a5d;
					padding: 14px 50px 14px 30px;
					display: block;
					position: relative;
					span {
						position: relative;
						z-index: 1;
					}
					&:after {
						position: absolute;
						content: '';
						width: 100%;
						height: calc(100% + 1px);
						left: 0;
						top: -1px;
						background: #d3dbe2;
						opacity: 0;
					}
					&:hover {
						color: #3f85b9;
						&:after {
							opacity: 1;
						}
						&:before {
							color: #3f85b9;
						}
					}
				}
			}
			li.has-children {
				a {
					&:before {
						content: "\e92f";
						font-family: 'wcmp' !important;
						font-style: normal;
						font-weight: normal;
						font-variant: normal;
						text-transform: none;
						line-height: 1;
						-webkit-font-smoothing: antialiased;
						-moz-osx-font-smoothing: grayscale;
						position: absolute;
						right: 30px;
						top: 50%;
						transform: translateY(-50%);
						z-index: 1;
					}
				}
			}
			li.active {
				a {
					color: #3f85b9;
					&:after {
						opacity: 1;
					}
					&:before {
						color: #3f85b9;
					}
				}
			}
		}
		.select-cat-button-holder {
			width: 33.33%;
			float: left;
			position: relative;
			height: 100%;
			.final-cat-button {
				position: absolute;
				top: 0;
				bottom: 0;
				left: 0;
				right: 0;
				margin: auto;
				width: 193px;
				max-width: 100%;
				height: 168px;
				text-align: center;
				button {
					position: absolute;
					top: 50%;
					left: 0;
					right: 0;
					margin: auto;
					transform: translateY(-50%);
					width: 80%;
				}
			}
		}
		.product-search-wrapper {
			.form-text {
				display: inline-block;
				vertical-align: middle;
				font-weight: 400;
				color: #333b3d;
				margin-right: 15px;
			}
			.form-input {
				display: inline-block;
				vertical-align: middle;
				width: 524px;
				max-width: 100%;
				height: 39px;
				border: 1px solid #c5c5c5;
				padding: 3px 3px 3px 55px;
				position: relative;
				border-radius: 4px;
				&:before {
					position: absolute;
					content: '\e93e';
					font-family: 'wcmp' !important;
					font-style: normal;
					font-weight: normal;
					font-variant: normal;
					text-transform: none;
					line-height: 1;
					-webkit-font-smoothing: antialiased;
					-moz-osx-font-smoothing: grayscale;
					font-size: 22px;
					position: absolute;
					left: 18px;
					top: 50%;
					transform: translateY(-50%);
				}
				input {
					background: transparent;
					border: 0;
					width: 100%;
					height: 100%;
					padding: 2px;
					&:focus {
						outline: none;
					}
				}
			}
			.list-group {
				z-index: 2;
				position: relative;
				left: -56px;
				top: 15px;
				display: inline-block;
				max-height: 326px;
				overflow: auto;
				width: 700px;
				overflow: auto;
				.list-group-item {
					border-radius: 0 !important;
					padding: 20px 28px;
					width: 700px;
					overflow: auto;
					cursor: pointer;
					p {
						color: #212121;
						margin-bottom: 3px;
					}
					&:hover {
						background: #edf1f4;
						color: #3f85b9;
						p {
							color: #3f85b9;
						}
					}
				}
			}
		}
		.cat-step2 {
			.form-group {
				input {
					width: 350px;
					max-width: 100%;
				}
				label {
					margin-right: 15px;
				}
			}
		}
		.breadcrumb {
			margin: 0;
			display: inline-block;
			vertical-align: middle;
			>li {
				+ {
					li {
						&::before {
							content: ">";
							color: #626c6f;
							padding: 0 8px;
						}
					}
				}
			}
		}
		.reset-btn {
			display: inline-block;
			vertical-align: middle;
			margin-left: 20px;
			i {
				vertical-align: middle;
				margin-right: 5px;
			}
			span {
				text-decoration: underline;
				vertical-align: middle;
			}
		}
		.panel-heading {
			h1 {
				.primary-color {
					span {
						opacity: 0.7;
					}
				}
			}
		}
	}
}
.cat-step3 {
	.product-title-wrap.product-add-mode {
		.editing-content {
			display: inline-block;
		}
		.grey-blockquote {
			.editable-content-button {
				display: none;
			}
			.editabble-button {
				display: none;
			}
		}
	}
	.panel-heading {
		padding: 0;
	}
	.cat-breadcrumb-wrap {
		margin-bottom: 15px;
		overflow: hidden;
		padding: 10px;
		background: #fff;
		border: 1px solid #d3dbe2;
		.wcmp-breadcrumb {
			margin: 0;
			padding: 4px 5px 4px 40px;
			background: url(../../images/cat-icon.png) no-repeat left top 13px;
			margin-top: -10px;
			li {
				margin-top: 12px;
			}
		}
		.multiple-cat-hierarchy {
			margin: 0;
			padding: 4px 0 4px 25px;
			background: url(../../images/multiple-cat-icon.png) no-repeat left center;
			.multi-cat-choose-dflt-btn {
				font-weight: normal;
				color: #797b7b;
				i {
					text-decoration: none !important;
					color: #212121;
					margin-left: 5px;
				}
			}
		}
	}
	.product-title-wrap {
		padding: 20px;
		margin-bottom: 20px;
		border: 1px solid #d4dbe3;
		border-left-width: 4px;
		background: #fff;
		display: inline-block;
		width: 100%;
		.product-title-inner {
			position: relative;
			width: calc(100% - 350px);
			max-width: 100%;
			p {
				&:last-child {
					margin-bottom: 0;
				}
				label {
					min-width: 92px;
					margin: 0;
				}
			}
		}
		.editing-content {
			vertical-align: middle;
			display: none;
			width: 405px;
			max-width: 100%;
		}
		#product_visiblity {
			right: 16px;
			z-index: 9;
		}
		.gtin-detal {
			margin-bottom: 0;
		}
		.cat-visiblity {
			text-align: right;
		}
	}
	.pro-view {
		word-break: break-word;
	}
	[data-target="#product_visiblity"] {
		border: 1px solid #bdbdbd;
		padding: 0px 4px;
		font-size: 12px;
		color: #212121;
		.wcmp-font {
			text-decoration: none;
			font-size: 12px;
		}
	}
}
.product-visibility-toggle-inner {
	padding: 15px;
}
.dropdown-panel {
	background: #fff;
	width: 238px;
	box-shadow: 0 10px 10px rgba(0, 0, 0, 0.11);
	border: 1px solid #d3dbe2;
	position: absolute;
	right: 16px;
	z-index: 1;
	background: #fff;
	width: 238px;
	box-shadow: 0 10px 10px rgba(0, 0, 0, 0.11);
	border: 1px solid #d3dbe2;
	position: absolute;
	z-index: 1;
	.form-group {
		margin-left: 0;
		margin-right: 0;
		margin-bottom: 0;
		input {
			margin-right: 6px;
		}
		span {
			display: inline-block;
			vertical-align: middle;
			width: calc(100% - 31px);
		}
		label {
			width: 100%;
		}
	}
	.wcmp-vendor_stock_alert {
		padding: 15px;
	}
	hr {
		margin: 9px 0 19px;
	}
	.btn-sm {
		margin-right: 5px;
	}
	.list-group {
		li {
			border-top: solid 1px #ddd;
			&:first-child {
				border: 0;
			}
			a {
				padding: 8px;
				display: block;
			}
		}
		li.active {
			background: #f3f3f3;
		}
	}
}
.has-multiple-cat {
	float: left;
	width: calc(100% - 430px);
	+ {
		.pull-right {
			margin: 19px 0 0;
			padding-bottom: 10px;
		}
	}
}
.cat-breadcrumb {
	display: inline-block;
	vertical-align: middle;
}
#multi_cat_hierarchy_visiblity {
	margin-top: 36px;
}
.editable-content-button {
	background: transparent;
	padding: 0;
	color: #7eaed1;
	box-shadow: none;
	border: none;
	margin: 0 0 0 10px;
	i {
		text-decoration: underline;
	}
	span {
		text-decoration: underline;
	}
}
.editabble-button {
	background: transparent;
	padding: 0;
	color: #7eaed1;
	box-shadow: none;
	border: none;
	margin: 0 0 0 10px;
	i {
		text-decoration: underline;
	}
	span {
		text-decoration: underline;
	}
}
[data-target="#multi_cat_hierarchy_visiblity"][aria-expanded="true"] {
	.wcmp-font.ico-downarrow-2-icon {
		&::before {
			content: '\e938';
		}
	}
}
[data-target="#product_visiblity"][aria-expanded="true"] {
	.wcmp-font.ico-downarrow-2-icon {
		&::before {
			content: '\e938';
		}
	}
}
.wcmp-product-cat-level {
	.mCSB_container {
		margin-right: 0 !important;
		width: 100%;
		min-height: 100%;
	}
}
.fc-content-skeleton {
	tr {
		background: transparent;
	}
}
.fc-toolbar {
	.fc-state-active {
		z-index: 1;
	}
	.ui-state-active {
		z-index: 1;
	}
}
.product-import.wcmp_displaybox2m {
	margin-bottom: 15px;
	text-align: left;
	overflow: hidden;
	border: solid 1px #a1aeb7;
	border-left: solid 7px #a1aeb7;
	padding: 2px;
	h4 {
		color: #555;
		display: inline-block;
		margin: 0;
		vertical-align: middle;
		padding: 10px;
		width: calc(100% - 155px);
	}
	h3 {
		margin-bottom: 0;
		color: #3f85b9;
		font-size: 16px;
		display: inline-block;
		vertical-align: middle;
		font-weight: bold;
		margin: 0;
		line-height: 21px;
		padding: 10px 15px;
		background: #e4e9ed;
		width: 150px;
		text-align: right;
		position: relative;
		&:after {
			content: '';
			position: absolute;
			top: 0;
			left: -3px;
			width: 1px;
			height: 100%;
			background: #d2dbe2;
		}
		sup {
			font-size: inherit;
			margin-right: 3px;
			top: 0;
		}
	}
	.woocommerce-Price-currencySymbol {
		font-size: 20px;
		margin-right: 3px;
		vertical-align: top;
	}
}
.wcmp_displaybox2 {
	margin-bottom: 15px;
	text-align: left;
	overflow: hidden;
	border: solid 1px #a1aeb7;
	border-left: solid 7px #a1aeb7;
	padding: 2px;
	h4 {
		color: #555;
		display: inline-block;
		margin: 0;
		vertical-align: middle;
		padding: 10px;
		width: calc(100% - 155px);
	}
	h3 {
		margin-bottom: 0;
		color: #3f85b9;
		font-size: 16px;
		display: inline-block;
		vertical-align: middle;
		font-weight: bold;
		margin: 0;
		line-height: 21px;
		padding: 10px 15px;
		background: #e4e9ed;
		width: 150px;
		text-align: right;
		position: relative;
		&:after {
			content: '';
			position: absolute;
			top: 0;
			left: -3px;
			width: 1px;
			height: 100%;
			background: #d2dbe2;
		}
		sup {
			font-size: inherit;
			margin-right: 3px;
			top: 0;
		}
	}
	.woocommerce-Price-currencySymbol {
		font-size: 20px;
		margin-right: 3px;
		vertical-align: top;
	}
}
.wcmp_displaybox3 {
	border: 1px solid #dfdfdf;
	box-shadow: 0 3px 0 1px rgba(0, 0, 0, 0.05);
	margin: 25px 0 0;
	padding: 10px 2%;
	width: 98%;
	background: #fff;
	color: #3f3f3f;
	font-size: 15px;
	font-weight: 400;
	line-height: 30px;
	width: 100%;
	text-align: center;
	h3 {
		color: #3f85b9;
		font-size: 27px;
		line-height: 30px;
		margin: 0;
	}
}
.stat-detail-row {
	.wcmp_displaybox3 {
		float: left;
		width: 30%;
		margin-right: 5%;
		&:nth-child(3n+3) {
			margin-right: 0;
		}
	}
}
.panel-info {
	background: #39677f;
	border-left: 5px solid #39677f;
	color: #fff;
	margin: 0;
}
.multi_input_block_manupulate {
	float: right;
	margin: 11px 0 0 !important;
	cursor: pointer;
	width: 15px;
	height: 15px;
	background: #ccc;
	text-align: center;
	line-height: 15px;
	border-radius: 50%;
	&:hover {
		background: #3f85b9;
		color: #fff;
	}
}
.multi_input_block_manupulate.button-secondary {
	margin-left: 5px !important;
}
p.description {
	font-size: 13px;
	font-style: italic;
	font-weight: normal;
	margin: 4px 0 0;
}
.img_tip {
	display: inline-block;
	margin-left: 5px;
	position: relative;
	&:after {
		content: '\e92a';
		font-family: 'wcmp' !important;
		font-size: 16px;
		color: #000;
		cursor: help;
	}
}
.tool_tip {
	position: relative;
	float: right;
	top: -17px;
	right: -15px;
	&:after {
		content: '\e92a';
		font-family: 'wcmp' !important;
		font-size: 16px;
		color: #000;
		position: absolute;
		top: 50%;
		right: -7px;
		transform: translateY(-50%);
		cursor: help;
	}
}
.qtip-content {
	color: #fff;
	line-height: 15px;
}
.checkbox-group-addon {
	div {
		margin-bottom: 8px;
		label {
			margin: 0 0 0 4px;
		}
	}
}
.wcmp_table_holder {
	clear: both;
}
.staff-detail-wrap {
	clear: both;
	border: 0;
	padding: 0;
}
.sub_vendor_error {
	clear: both;
	color: #a94442;
}
.sub_vendor_success {
	color: #3c763d !important;
}
.vendor-msg {
	display: none;
}
#wcmp-vendor-orders_wrapper {
	.row {
		>.col-sm-6 {
			width: auto;
		}
	}
}
#vendor_transactions_wrapper {
	.row {
		>.col-sm-6 {
			width: auto;
		}
	}
}
.wcmp-order-totals-items {
	.wc-used-coupons {
		.wc_coupon_list {
			.code {
				display: inline-block;
				position: relative;
				padding: 0 .5em;
				background-color: #fff;
				border: 1px solid #aaa;
				box-shadow: 0 1px 0 #dfdfdf;
				border-radius: 4px;
				margin-right: 5px;
				margin-top: 5px;
			}
		}
	}
}
#wcmp_order_data_refunds {
	.wcmp-order-actions {
		padding-top: 20px;
	}
}
select[name="wcmp-vendor-orders_length"] {
	margin-left: 10px;
	margin-right: 10px;
}
#customer_questions {
	.qna-date {
		display: block;
	}
}
.btn.btn-danger {
	background: #b41e1e !important;
	border-color: #b41e1e !important;
	&:hover {
		background: #202627 !important;
		border-color: #202627 !important;
	}
}
.customer-detail-inner {
	border: 1px solid #d3dbe2;
	padding: 15px;
	margin: 10px 5px;
	h3 {
		margin-bottom: 10px;
	}
	p {
		margin-bottom: 5px;
	}
}
.icon-header {
	margin-bottom: 25px;
	>span {
		float: left;
		margin: 0 8px 0 -5px;
		i {
			font-size: 50px;
		}
	}
	h2 {
		font-size: 22px;
		margin: 0 0 4px;
		padding-top: 1px;
	}
	h3 {
		color: inherit;
		.processing {
			color: #5b841b;
		}
		.on-hold {
			color: #94660c;
		}
		.completed {
			color: #2e4453;
		}
		.cancelled {
			color: #777;
		}
		.refunded {
			color: #777;
		}
		.pending {
			color: #777;
		}
		.failed {
			color: #761919;
		}
	}
}
.order_download_permissions {
	.select2-container {
		width: calc(100% - 143px) !important;
	}
}
.download-product-permission {
	input.form-control {
		width: 400px;
		max-width: 100%;
	}
}
.order-action {
	li {
		i {
			margin-right: 5px;
			font-size: 20px;
			vertical-align: middle;
		}
	}
	.list-group-item {
		border: 0;
		border-top: 1px solid #d3dbe2;
		&:first-child {
			border: 0;
		}
		a {
			display: table;
			i {
				display: table-cell;
				vertical-align: top;
				padding-right: 10px;
			}
		}
	}
	form {
		margin-bottom: 5px;
		select.form-control {
			width: 250px;
			max-width: 100%;
			margin-right: 5px;
		}
	}
}
.order-notes {
	.order-note {
		padding: 15px 12px;
		background: #dde2e8;
		margin-bottom: 13px;
		position: relative;
		color: #dde2e8;
		p {
			color: #626c6f;
			&:last-child {
				margin: 0;
			}
		}
		span {
			color: #212121;
		}
		&:after {
			content: '';
			position: absolute;
			left: 25px;
			bottom: -9px;
			width: 0;
			height: 0;
			border-width: 11px 10px 0 10px;
			border-style: solid;
			border-color: inherit;
			border-left-color: transparent;
			border-right-color: transparent;
		}
	}
	.order-note.customer-note {
		background: #a7cedc;
		color: #a7cedc;
	}
	.order-note.system-note {
		background: #d7cad2;
		color: #d7cad2;
	}
}
.tools-item {
	overflow: hidden;
	label {
		margin-bottom: 0;
	}
	p {
		margin-top: 7px;
	}
	.wcmp_vendor_clear_transients {
		margin-top: 5px;
	}
	.col-md-3 {
		text-align: right;
		text-align: center;
		margin-top: 10px;
	}
}
.top-order-note {
	td {
		padding: 5px;
	}
	th {
		padding-right: 10px;
	}
}
.order-detail-top-panel {
	>.panel-heading {
		overflow: visible !important;
	}
}
.order-address-info {
	border-top: 0 !important;
	hr {
		margin: 9px 0 15px;
	}
	.col-md-4 {
		.border {
			padding: 20px 25px;
			height: 100%;
			h3 {
				margin-bottom: 8px;
			}
			p {
				margin-bottom: 3px;
			}
			.customer-detail {
				display: table;
				.icon {
					display: table-cell;
					padding-right: 10px;
					vertical-align: top;
					max-width: 62px;
					i {
						font-size: 25px;
						margin-right: 10px;
						background: #d3dce1;
						padding: 16px 14px;
						vertical-align: top;
						display: inline-block;
					}
				}
				p {
					margin-bottom: 1px;
				}
			}
		}
	}
}
.withdrawal-transaction-wrapper {
	overflow: auto;
}
.pending-vendor-dashboard {
	.navbar-default.sidebar {
		&:after {
			content: '';
			width: 100%;
			height: 100%;
			top: 50px;
			position: absolute;
			left: 0;
			background: rgba(0, 0, 0, 0.65);
			clear: none;
		}
	}
}
.rejected-vendor-dashboard {
	.navbar-default.sidebar {
		&:after {
			content: '';
			width: 100%;
			height: 100%;
			top: 50px;
			position: absolute;
			left: 0;
			background: rgba(0, 0, 0, 0.65);
			clear: none;
		}
	}
}
.wcmp-rejected-vendor-notice {
	padding: 20px;
}
.wcmp-pending-vendor-notice {
	padding: 20px;
}
.note-clm-wrap {
	padding-left: 30px;
	position: relative;
	&:after {
		content: '';
		width: 1px;
		height: 100%;
		background: #ccc;
		position: absolute;
		top: 0;
		left: 0;
	}
	.note-clm {
		&:last-of-type {
			margin-bottom: 0;
		}
	}
}
.note-clm {
	display: block;
	padding: 14px 17px;
	max-width: 60%;
	margin: 0 5% 20px 0;
	border: 1px solid #ccc;
	position: relative;
	border-radius: 6px;
	&:before {
		width: 13px;
		height: 13px;
		border: 2px solid #fff;
		border-radius: 100px;
		margin: 16px 0 0 -4px;
		box-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), inset 0 1px 1px rgba(0, 0, 0, 0.1);
		background: #fd5869;
		content: "";
		position: absolute;
		top: 0;
		left: -33px;
		z-index: 1;
		box-sizing: border-box;
	}
	&:after {
		width: 9px;
		height: 9px;
		border-width: 0 0 1px 1px;
		border-style: solid;
		border-color: #ccc;
		background: #fff;
		-webkit-transform: rotate(45deg);
		-moz-transform: rotate(45deg);
		-ms-transform: rotate(45deg);
		-o-transform: rotate(45deg);
		transform: rotate(45deg);
		content: "";
		position: absolute;
		top: 18px;
		left: -6px;
	}
	p.note-meta {
		margin: 0;
		display: inline-block;
		color: #969696;
	}
	p.note-meta.note_owner {
		margin-left: 10px;
	}
}
.note-description {
	margin: 0 0 21px;
}
.wcmp-regi-form-row {
	margin-bottom: 20px;
	overflow: hidden;
	label {
		width: 25%;
		float: left;
		font-weight: normal;
	}
	input[type="text"] {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
	}
	input[type="url"] {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
	}
	input[type="password"] {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
	}
	input[type="email"] {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
	}
	input[type="file"] {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
	}
	textarea {
		padding: 3px 5px;
		box-shadow: none;
		line-height: 20px;
		border: 1px solid #c5c5c5;
		height: 34px;
		font-size: 14px;
		border-radius: 4px;
		float: left;
		width: 50%;
		height: 100px;
	}
}
.wcmp_regi_form_box {
	.reg_header2 {
		border-top: 1px solid #ddd;
		padding-top: 30px;
		margin-top: 32px;
		font-size: 21px;
		padding-bottom: 10px;
	}
}
.wcmp-regi-radio-inp-holder {
	float: left;
	width: 50%;
}
.reapply_vendor_application_form {
	.wcmp-regi-12 {
		input[type=file] {
			padding: 5px 5px;
		}
	}
}
.wcmp-do-change-pass {
	margin-top: 6px;
}
.zone-component {
	position: relative;
	.shipping-zone-list {
		i {
			margin-right: 8px;
		}
		+ {
			.form-group {
				margin-top: 15px;
			}
		}
	}
}
.wcmp-shipping-zone-methods {
	.method_disabled {
		text-decoration: line-through;
	}
}
.zone-method-table {
	.col-actions {
		white-space: nowrap;
	}
}
#usage_restriction_coupon_data {
	.form-group-row {
		border-bottom: solid 1px #d3dbe2;
		margin-bottom: 20px;
		padding-bottom: 20px;
	}
	.coupon-products-wrap {
		.select2.select2-container {
			margin-bottom: 10px;
		}
	}
}
.vendor-announcements {
	#tabs-1.ui-tabs.ui-widget.ui-widget-content.ui-corner-all {
		background: rgba(0, 0, 0, 0) none repeat scroll 0 0;
		border: 0 solid #dddddd;
		color: #333333;
		padding: 0 !important;
		border-radius: 0px !important;
	}
	#tabs-1 {
		.ui-widget-header {
			background: transparent none repeat scroll 0 0 !important;
			border: 0 solid #dcdcdc !important;
			border-bottom-width: 1px !important;
			border-radius: 0 !important;
			color: #ffffff;
			font-weight: bold;
			padding: 40px 0 !important;
			text-align: center;
			width: 100%;
		}
	}
	.ui-tabs {
		.ui-tabs-panel {
			padding: 0 !important;
		}
	}
	#tabs-1.ui-tabs {
		.ui-tabs-nav {
			li {
				border-bottom-width: 0;
				border-radius: 0px;
				display: inline-block !important;
				float: none !important;
				list-style: outside none none;
				margin: 0 8px 0 0;
				padding: 0;
				position: relative;
				top: 0;
				white-space: nowrap;
				border: 1px solid #b1b1b1 !important;
			}
		}
	}
	.ui-state-default {
		background: #f4f4f4 none repeat scroll 0 0;
		background-image: none !important;
		border: 0 solid #fbd850 !important;
		border-radius: 0;
		font-size: 15px;
		font-weight: bold;
		background: #f4f4f4 !important;
		background-image: none !important;
		border: 1px solid #e9e9e9 !important;
		border-top: none !important;
		color: #868686 !important;
		font-weight: 700 !important;
		&:hover {
			background: #fff;
		}
		a {
			color: #a0a0a0 !important;
			&:link {
				color: #a0a0a0 !important;
			}
			&:visited {
				color: #a0a0a0 !important;
			}
		}
		.msg_date_box {
			color: #868686 !important;
		}
		.msg_title_box {
			color: #868686 !important;
		}
		.msg_stat {
			ul {
				li {
					a {
						color: #3e3e3e !important;
						&:link {
							color: #3e3e3e !important;
						}
						&:visited {
							color: #3e3e3e !important;
						}
						&:hover {
							color: #fc482f !important;
						}
					}
					a.active {
						color: #fc482f !important;
					}
				}
			}
		}
	}
	.ui-widget-content {
		.ui-state-default {
			background: #f4f4f4 none repeat scroll 0 0;
			background-image: none !important;
			border: 0 solid #fbd850 !important;
			border-radius: 0;
			font-size: 15px;
			font-weight: bold;
			background: #f4f4f4 !important;
			background-image: none !important;
			border: 1px solid #e9e9e9 !important;
			border-top: none !important;
			color: #868686 !important;
			font-weight: 700 !important;
			&:hover {
				background: #fff;
			}
			.msg_date_box {
				color: #868686 !important;
			}
			.msg_title_box {
				color: #868686 !important;
			}
		}
		.ui-state-active {
			background: #ffffff none repeat scroll 0 0;
			border: 0 solid #fbd850 !important;
			border-radius: 0;
			font-size: 15px;
			font-weight: bold;
			background: #ffffff !important;
			border: 1px solid #e9e9e9 !important;
			border-top: none !important;
			color: #222222 !important;
			font-weight: 700;
		}
		.ui-state-hover {
			border: 0 solid #fbcb09;
			background: none;
			font-weight: bold;
			color: #222222;
		}
		.ui-state-focus {
			border: 0 solid #fbcb09;
			background: none;
			font-weight: bold;
			color: #222222;
		}
		background: #fff none repeat scroll 0 0 !important;
		border: medium none !important;
		color: #333333 !important;
	}
	.ui-widget-header {
		.ui-state-default {
			background: #f4f4f4 none repeat scroll 0 0;
			background-image: none !important;
			border: 0 solid #fbd850 !important;
			border-radius: 0;
			font-size: 15px;
			font-weight: bold;
			background: #f4f4f4 !important;
			background-image: none !important;
			border: 1px solid #e9e9e9 !important;
			border-top: none !important;
			color: #868686 !important;
			font-weight: 700 !important;
			&:hover {
				background: #fff;
			}
			.msg_date_box {
				color: #868686 !important;
			}
			.msg_title_box {
				color: #868686 !important;
			}
		}
		.ui-state-active {
			background: #ffffff none repeat scroll 0 0;
			border: 0 solid #fbd850 !important;
			border-radius: 0;
			font-size: 15px;
			font-weight: bold;
			background: #ffffff !important;
			border: 1px solid #e9e9e9 !important;
			border-top: none !important;
			color: #222222 !important;
			font-weight: 700;
		}
		.ui-state-hover {
			border: 0 solid #fbcb09;
			background: none;
			font-weight: bold;
			color: #222222;
		}
		.ui-state-focus {
			border: 0 solid #fbcb09;
			background: none;
			font-weight: bold;
			color: #222222;
		}
	}
	.ui-state-active {
		background: #ffffff none repeat scroll 0 0;
		border: 0 solid #fbd850 !important;
		border-radius: 0;
		font-size: 15px;
		font-weight: bold;
		background: #ffffff !important;
		border: 1px solid #e9e9e9 !important;
		border-top: none !important;
		color: #222222 !important;
		font-weight: 700;
		a {
			color: #3e3e3e !important;
			&:link {
				color: #3e3e3e !important;
			}
			&:visited {
				color: #3e3e3e !important;
			}
		}
	}
	.ui-state-hover {
		border: 0 solid #fbcb09;
		background: none;
		font-weight: bold;
		color: #222222;
	}
	.ui-state-focus {
		border: 0 solid #fbcb09;
		background: none;
		font-weight: bold;
		color: #222222;
	}
	.ui-accordion {
		.ui-accordion-header {
			.ui-accordion-header-icon {
				display: none;
			}
			margin-top: 0px !important;
			clear: both;
			overflow: hidden;
			width: 100%;
			overflow: visible;
			&:after {
				content: ".";
				display: block;
				height: 0;
				clear: both;
				visibility: hidden;
			}
		}
		.ui-accordion-icons {
			padding: 0px !important;
		}
		.ui-accordion-content {
			color: #222;
			font-weight: 300;
			font-size: 15px;
			border: 1px solid #e9e9e9 !important;
			border-top: none !important;
			border-radius: 0 !important;
			padding: 0 !important;
			p {
				&:last-of-type {
					margin: 0;
				}
			}
			.wcmp_anouncement-content {
				padding: 30px 5% !important;
			}
		}
	}
	.msg_date_box {
		width: 15%;
		min-height: 75px;
		border-right: 1px solid #dcdcdc;
		font-size: 13px;
		font-weight: 700;
		float: left;
		text-align: center;
		padding-top: 12px;
		span {
			font-size: 23px;
		}
	}
	.msg_title_box {
		min-height: 75px;
		font-size: 15px;
		float: left;
		width: 77%;
		padding: 14px 10px;
		span.title {
			font-weight: 700;
		}
		span.title.after_show {
			padding-top: 10px;
		}
		span.mormaltext {
			font-weight: 300;
			overflow: hidden;
			white-space: nowrap;
			margin-top: 4px;
			text-overflow: ellipsis;
			display: inline-block;
			width: 100%;
		}
	}
	.msg_arrow_box {
		min-height: 75px;
		padding: 10px;
		width: 8%;
		float: left;
		text-align: center;
		position: relative;
		color: #868686;
		font-size: 16px;
		position: relative;
		.msg_stat_click {
			position: absolute;
			top: 50%;
			left: 0;
			right: 0;
			transform: translateY(-50%);
		}
	}
	.msg_stat {
		min-width: 100px;
		border: 1px solid #dcdcdc;
		background: #f4f4f4;
		position: absolute;
		z-index: 1;
		right: 0;
		top: 70%;
		ul {
			list-style: none;
			padding: 0px;
			margin: 0px;
			li {
				border-bottom: 1px solid #dcdcdc;
				color: #3e3e3e !important;
				font-size: 15px;
				padding: 5px 10px;
				text-align: left;
				a {
					color: #3e3e3e !important;
					display: inline-block;
					width: 100%;
					text-decoration: none;
					font-size: 12px;
				}
			}
		}
	}
	.msg_title_box2 {
		min-height: 60px;
		font-size: 19px;
		float: left;
		width: 90%;
		padding: 20px 33px !important;
		color: #000;
	}
	.msg_arrow_box2 {
		min-height: 60px;
		padding: 20px 10px;
		width: 8%;
		float: left;
		text-align: center;
		position: relative;
		color: #868686;
		font-size: 16px;
	}
	.university_text {
		color: #000;
		padding: 0px 3px !important;
		font-size: 15px;
		font-weight: 500;
		h3 {
			color: #000;
			font-weight: 700;
			font-size: 15px !important;
		}
		a {
			color: #ff4141 !important;
			font-size: 15px;
		}
	}
	.ajax_loader_class_msg {
		width: 100%;
		position: absolute;
		z-index: 8888;
		background-color: #ddd;
		opacity: 0.5;
		height: 95%;
		text-align: center;
		display: none;
		img {
			margin: 20% auto;
		}
	}
}
.university_text {
	iframe {
		padding: 30px 0;
	}
}
.wcmp_hide_message {
	display: none !important;
}
.wcmp_hide_message2 {
	display: none !important;
}
.wcmp_hide_message3 {
	display: none !important;
}
.wcmp_hide_message4 {
	display: none !important;
}
#wcmp-vendor-ledger {
	td.debit {
		color: #761919;
	}
	td.credit {
		color: #5b841b;
	}
	.status {
		text-align: center;
		vertical-align: middle;
		i {
			display: inline-block;
			width: 24px;
			height: 24px;
			vertical-align: top;
			background: #fec40d;
			z-index: 1;
			border-radius: 50%;
			line-height: 25px;
			text-align: center;
			color: #fff;
		}
		i.unpaid {
			background: #fec40d;
			&:before {
				content: '\e958';
			}
		}
		i.completed {
			background: #37a972;
			&:before {
				content: '\e950';
			}
		}
		i.paid {
			background: #37a972;
			&:before {
				content: '\e950';
			}
		}
		i.cancelled {
			background: #c84040;
			&:before {
				content: '\e94f';
			}
		}
		i.refunded {
			background: #349bd5;
			&:before {
				content: '\e959';
			}
		}
		i.failed {
			background: #f36f59;
			&:before {
				content: '\e954';
			}
		}
	}
	.ref_type {
		.type.commission {
			background: #c6e1c6;
			color: #5b841b;
		}
		.type.withdrawal {
			background: #f8dda7;
			color: #94660c;
		}
		.type.refund {
			background: #eba3a3;
			color: #761919;
		}
		.type {
			>span {
				margin: 0 1em;
				overflow: hidden;
				text-overflow: ellipsis;
			}
		}
	}
}
.wcmp-vendor-ledger-report-row {
	.ledger-box-wrap {
		margin-bottom: 20px;
	}
	.widget.widget-stats {
		position: relative;
		color: #fff;
		padding: 15px;
		border-radius: 3px;
		h4 {
			color: #fff;
		}
		.stats-info {
			.number {
				font-size: large;
				font-weight: bold;
			}
		}
	}
	.widget-stats {
		.stats-icon {
			font-size: 42px;
			height: 56px;
			width: 56px;
			text-align: center;
			line-height: 56px;
			margin-left: 15px;
			color: #fff;
			position: absolute;
			right: 15px;
			top: 15px;
			opacity: .5;
			i.wcmp-font {
				font-weight: 500;
			}
		}
	}
}
.wcmp_order_items_wrapper {
	table.woocommerce_order_items {
		small.refunded {
			display: block;
			color: #a00;
			white-space: nowrap;
			margin-top: .5em;
		}
	}
	.wcmp-order-totals {
		.refunded-total {
			color: #a00;
		}
		.amount {
			font-weight: 700;
		}
	}
}
.refund {
	.line_cost {
		text-align: right;
	}
}
@media screen and (max-width: 480px) {
	h1 {
		font-size: 21px;
		line-height: 28px;
	}
	h2 {
		font-size: 16px;
	}
	.heading-underline {
		margin-bottom: 25px;
	}
	.panel.panel-default.panel-pading {
		padding: 15px;
	}
	.wcmp-action-container {
		.btn {
			span {
				font-size: 0;
			}
			i {
				margin: 0;
			}
		}
	}
	.form-group {
		margin-bottom: 12px;
	}
	.form-control {
		height: 30px;
	}
	.form-horizontal {
		.control-label {
			.img_tip {
				margin: 7px 0 0 0;
			}
			font-size: 13px;
			padding-right: 20px;
		}
		font-size: 13px;
	}
	body {
		.ui-accordion {
			.ui-accordion-content {
				padding: 1em 1.2em;
			}
		}
		.woocommerce {
			table.form-table {
				.select2-container {
					min-width: auto !important;
				}
			}
		}
		.woocommerce-exporter {
			.woocommerce-exporter-options {
				td {
					.select2-container {
						width: auto !important;
					}
				}
			}
		}
	}
	.date-inp-wrap {
		.hasDatepicker {
			width: 123px;
			padding-left: 5px;
		}
	}
	.staticstics-panel-wrap {
		.panel-body {
			.wcmp-website-stat-list {
				li {
					width: 100%;
					margin: 0 0 10px;
					&:last-of-type {
						margin-bottom: 0;
					}
				}
			}
		}
	}
	form[name="wcmp_vendor_dashboard_orders"] {
		button.btn {
			height: 30px;
			padding: 3px 8px;
		}
	}
	.datatable-date-filder {
		button.btn {
			height: 30px;
			padding: 3px 8px;
		}
	}
	.frontend_product_manager_product_types {
		padding: 10px;
		#product_type {
			font-size: 12px;
		}
		.product_type_wrapper {
			.product_type.pro_title {
				+ {
					.col-md-6 {
						padding: 0 0 0 8px;
					}
				}
			}
		}
	}
	.products.content-padding {
		#product_cat {
			max-width: calc(100% - 203px);
			min-width: 120px;
			margin: 0;
			display: inline-block;
			font-size: 12px;
			padding-right: 15px !important;
			background-position: right 3px top 50%;
		}
		#product_types {
			font-size: 12px;
			width: 139px;
			padding-left: 3px;
			padding-right: 15px !important;
			background-position: right 3px top 50%;
		}
	}
	.product_search {
		.pro_search_key {
			width: calc(100% - 69px);
		}
	}
	form.stat-date-range {
		.panel-heading {
			.date-inp-wrap {
				input {
					width: 100%;
				}
			}
			.form-group {
				display: block;
				margin-bottom: 5px;
			}
			.to-text {
				display: block;
				text-align: center;
			}
		}
	}
}
@media (max-width: 768px) {
	.content-padding {
		padding: 20px;
	}
	.modal-dialog {
		margin: 0 auto;
	}
}
@media (max-width: 480px) {
	.content-padding {
		padding: 15px;
	}
}
@media screen and (max-width: 767px) {
	.mt-md-10 {
		margin-top: 10px;
	}
	.mt-md-15 {
		margin-top: 15px;
	}
	.wcmp-action-container {
		top: 61px;
		right: 20px;
		.btn {
			font-size: 12px;
			padding: 3px 9px !important;
		}
	}
	form[name="wcmp_vendor_dashboard_orders"] {
		float: none;
		margin: 0 auto;
		display: table;
		text-align: center;
		.form-group {
			display: inline-block;
			vertical-align: top;
			margin-bottom: 5px;
		}
		button {
			display: inline-block;
			vertical-align: top;
			margin-bottom: 5px;
		}
	}
	.datatable-date-filder {
		.form-group {
			display: inline-block;
			vertical-align: top;
			margin-bottom: 5px;
		}
		button {
			display: inline-block;
			vertical-align: top;
			margin-bottom: 5px;
		}
	}
	.reapply_vendor_application_form {
		.wcmp-regi-12 {
			input[type=text] {
				width: 100%;
			}
			input[type=url] {
				width: 100%;
			}
			input[type=file] {
				width: 100%;
			}
		}
	}
	.note-clm {
		max-width: 100%;
		margin-right: 0;
	}
}
@media screen and (max-width: 1080px) {
	.full-1080 {
		width: 100% !important;
	}
}
@media screen and (max-width: 768px) {
	.full-768 {
		width: 100% !important;
	}
	body {
		.ui-accordion {
			.ui-accordion-header {
				padding-top: 8px;
				padding-bottom: 8px;
				font-size: 14px;
			}
		}
	}
	.progress {
		height: 22px;
		.progress-bar {
			line-height: 19px;
		}
	}
	.vendor-product {
		td.image {
			text-align: center;
		}
	}
	.content-padding {
		&:not(.dashboard) {
			.dataTables_wrapper.dt-bootstrap {
				.dataTables_paginate {
					text-align: center;
					margin-top: 8px;
					li {
						a {
							padding: 5px 10px;
							font-size: 13px;
						}
					}
				}
			}
		}
	}
	.side-collapse.in {
		opacity: 0;
	}
	.navbar {
		.topbar-left {
			width: 120px;
			.site-logo {
				img {
					max-height: 36px;
				}
			}
		}
	}
	ul.nav {
		.login-user {
			.dropdown-menu.dropdown-user {
				width: 175px;
				min-width: 160px;
				i {
					font-size: 15px;
					margin-right: 6px;
				}
				a {
					font-size: 13px;
					padding: 1px 10px;
				}
			}
			a {
				padding: 16px 0 12px 0;
			}
		}
	}
	.top-user-nav {
		width: 78px;
	}
	.btm-nav-fixed {
		margin-top: 7px;
	}
	.sidebar.navbar-default {
		li {
			&:not(:first-of-type) {
				margin-top: 2px;
			}
		}
		ul {
			a {
				i {
					font-size: 18px;
					margin-right: 5px;
				}
				i.ico-downarrow-2-icon {
					font-size: 11px;
					right: 10px;
				}
			}
		}
		a {
			font-size: 12px;
			padding: 12px 26px 12px 12px;
		}
	}
	.navbar-default.sidebar {
		ul {
			ul {
				li {
					a {
						padding-left: 50px;
						padding-top: 8px;
						padding-bottom: 8px;
						font-size: 13px;
					}
				}
				margin-top: 1px;
				margin-bottom: 5px;
			}
		}
	}
	.navbar-default {
		.navbar-toggle {
			height: 56px;
			left: 120px;
			top: -56px;
		}
	}
	#page-wrapper {
		padding-bottom: 44px;
	}
	.btm-nav-fixed.nav {
		position: fixed;
		width: 100%;
		background: #fff;
		left: 0;
		bottom: 0;
		z-index: 9999;
		padding: 4px 0;
		text-align: center;
		box-shadow: 1px 0 3px rgba(0, 0, 0, 0.2);
		margin: 0;
		li {
			margin: 0;
			width: 25%;
			float: left;
			text-align: center;
		}
	}
	.navbar-toggle {
		margin-top: -43px;
	}
	.side-collapse {
		width: 200px;
		height: calc(100vh - 56px);
		overflow: auto;
	}
	.sidebar {
		.submenu {
			li {
				margin-top: 3px;
				a {
					padding-left: 49px;
				}
			}
		}
		.nav-third-level {
			li {
				margin-top: 3px;
			}
		}
	}
	.sidebar-logo {
		.vendor-profile-pic-holder {
			width: 80px;
			height: 80px;
		}
		h4 {
			font-size: 12px;
		}
	}
	#page-wrapper.large {
		position: relative;
		left: 200px;
	}
	.current-endpoint-title-wrapper {
		padding: 8px 20px;
		width: 100%;
		height: 38px;
		top: 56px;
		left: 0;
		.current-endpoint {
			font-size: 14px;
			margin-top: 0;
		}
		+ {
			.content-padding {
				padding-top: 114px;
			}
		}
	}
	.side-collapse-container.overlay {
		.current-endpoint-title-wrapper {
			left: 200px;
		}
	}
	.top-navbar {
		height: 56px;
	}
	.navbar-static-top {
		top: 56px;
	}
	.stat-detail-row {
		.wcmp_displaybox3 {
			width: 45%;
			margin-right: 10%;
			&:nth-child(3n+3) {
				margin-right: 10%;
			}
			&:nth-child(2n+2) {
				margin-right: 0;
			}
		}
	}
	.tools-item {
		text-align: center;
	}
}
@media screen and (max-width: 640px) {
	.panel.panel-default.panel-pading {
		padding: 20px;
	}
	.btn.btn-default {
		font-size: 13px;
		padding: 3px 9px;
	}
	.btn.btn-secondary {
		font-size: 13px;
		padding: 3px 9px;
	}
	.wcmp-modal {
		.wcmp-modal-content {
			min-width: auto;
			width: 90%;
		}
	}
	.vendor-cover-wrap {
		img {
			min-height: auto;
		}
		.vendor-profile-pic-wraper {
			width: 120px;
			height: auto;
			overflow: visible;
			margin: auto;
			left: 0;
			right: 0;
			bottom: -72px;
			padding-bottom: 0;
			img {
				border-width: 5px;
			}
			.profile-pic-btn {
				bottom: 5px;
				right: 5px;
				width: auto;
				line-height: 10px;
				padding: 2px 5px;
				height: 25px;
				button {
					font-size: 0;
					.wcmp-font {
						font-size: 15px;
						line-break: 21px;
					}
				}
			}
		}
		.cover-pic-button {
			right: 0;
			bottom: 0;
			font-size: 0;
			button {
				padding: 5px;
				height: 25px;
				.wcmp-font {
					font-size: 15px;
				}
			}
		}
	}
	.wcmp_template_list {
		li {
			width: 400px;
			max-width: 100%;
			margin: 0 auto 15px !important;
			float: none;
		}
	}
	.stat-detail-row {
		.wcmp_displaybox3 {
			width: 100%;
			margin-right: 0% !important;
		}
	}
}
@media (min-width: 769px) {
	#page-wrapper {
		margin: 64px 0 0 284px;
	}
	#wrapper {
		position: relative;
	}
	.sidebar {
		z-index: 1;
		position: absolute;
		width: 284px;
	}
	.navbar-top-links {
		.dropdown-messages {
			margin-left: auto;
		}
		.dropdown-tasks {
			margin-left: auto;
		}
		.dropdown-alerts {
			margin-left: auto;
		}
	}
}
@media screen and (min-width: 768px) {
	.vendor-product {
		.row-actions {
			visibility: hidden;
		}
	}
}
@media screen and (min-width: 992px) and (max-width: 1200px) {
	.navbar-top-links {
		margin-top: 21px;
		li.notification-link {
			margin: 0 20px 0 0;
			span {
				font-size: 14px;
			}
			i.wcmp-font {
				font-size: 23px;
			}
		}
	}
}
@media screen and (max-width: 782px) {
	body.admin-bar {
		#wpadminbar {
			position: fixed;
		}
		.top-navbar {
			top: 46px;
		}
		.navbar-default {
			.navbar-toggle {
				top: -55px;
			}
		}
		.current-endpoint-title-wrapper {
			top: 102px;
		}
		.navbar-static-top {
			top: 102px;
		}
		.wcmp-action-container {
			top: 107px;
		}
	}
}
@media screen and (max-width: 1280px) {
	.staticstics-panel-wrap {
		.panel-body {
			.short-stat-info-list {
				li {
					>span.stat-icon {
						width: 29%;
						font-size: 23px;
						padding-right: 26px;
					}
				}
			}
			.wcmp-website-stat-list {
				li {
					font-size: 13px;
					mark {
						font-size: 12px;
					}
					i {
						font-size: 21px;
					}
				}
			}
		}
	}
	.key-perfomence-indicator {
		width: 300px;
		+ {
			.col-md-8 {
				width: calc(100% - 300px);
			}
		}
	}
}
@media screen and (max-width: 550px) {
	.staticstics-panel-wrap {
		.panel-body {
			.compare-stat-info {
				padding: 15px;
				select {
					display: block;
					margin: 8px 0 0;
				}
			}
		}
	}
}
@media screen and (max-width: 991px) {
	.key-perfomence-indicator {
		width: 300px;
		+ {
			.col-md-8 {
				width: 100%;
			}
		}
	}
	.tool_tip {
		right: -7px;
		&:after {
			font-size: 12px;
		}
	}
}
@media screen and (max-width: 1070px) {
	.vendor-products-qna-filters {
		float: right;
		width: 100%;
		padding-bottom: 13px;
		border-bottom: 1px solid #ddd;
		margin-bottom: 12px;
		.form-group {
			float: left;
			width: calc(100% - 100px);
			max-width: initial;
			margin-bottom: 0;
		}
	}
}
@media screen and (max-width: 600px) {
	table.responsive-table {
		thead {
			display: none;
		}
		tr {
			border-color: #eee;
			&:nth-of-type(even) {
				background: #f9f9f9;
			}
			&:first-child {
				td {
					&:first-child {
						border: 0 !important;
					}
				}
			}
		}
		td {
			display: block;
			padding: .7rem !important;
			text-align: left !important;
			border-width: 1px 0 0 !important;
			>span {
				display: table-cell;
				padding-left: 10px;
			}
			&:before {
				content: attr(data-th);
				font-weight: bold;
				width: 100px;
				vertical-align: top;
				display: table-cell;
				vertical-align: middle;
			}
		}
		caption {
			background-image: none;
		}
	}
	.blank-responsive-table {
		thead {
			display: none;
		}
	}
}
@media screen and (max-width: 1145px) {
	form[name="wcmp_vendor_dashboard_completed_stat_export"] {
		float: left;
		width: 100%;
		margin-top: 12px;
	}
}
@media screen and (max-width: 1024px) {
	.vendor-cover-wrap {
		.cover-pic-button {
			right: 20px;
			bottom: 20px;
			font-size: 13px;
			button {
				padding: 9px 10px;
			}
		}
	}
}
@media screen and (max-width: 1023px) {
	.frontend_product_manager_product_types {
		.form-group.product_type_wrapper {
			display: block;
			margin-bottom: 10px;
		}
		.form-group.is_virtual_wrapper {
			margin-left: 0;
		}
	}
}
@media (min-width: 768px) {
	.multi_input_block {
		.form-group {
			label {
				+ {
					.col-sm-9 {
						width: 75%;
					}
				}
			}
		}
	}
	.vendor-orders {
		form[name="wcmp_vendor_dashboard_orders"] {
			float: right;
		}
	}
	.datatable-date-filder {
		float: right;
	}
}
@media screen and (max-width: 1100px) {
	.product_search {
		width: 100%;
		padding: 15px 0;
		border-top: 1px solid #ddd;
		border-bottom: 1px solid #ddd;
		.pro_search_key {
			width: calc(100% - 74px);
		}
	}
	#product_bulk_actions {
		width: calc(100% - 63px);
		margin: 8px 0;
	}
	body {
		.product-filter-actions {
			.alignleft.actions {
				button {
					&:not(:last-of-type) {
						margin-right: 0;
					}
				}
			}
		}
	}
	.product_filters {
		li {
			float: none;
			margin-bottom: 15px;
		}
	}
	#product_cat {
		max-width: calc(100% - 270px);
		min-width: 147px;
	}
	form.stat-date-range {
		.panel-heading {
			h3 {
				display: block;
				padding-bottom: 5px;
				+ {
					.form-group {
						margin-left: 0;
					}
				}
			}
		}
	}
}
@media screen and (max-width: 892px) {
	.select-product-cat-wrapper {
		.cat-intro {
			.serach-product-cat-wrapper {
				form {
					.form-control {
						width: 100%;
					}
					>.btn {
						margin-top: 10px;
					}
				}
			}
		}
	}
}
@media screen and (max-width: 1000px) {
	.select-product-cat-wrapper {
		.cat-intro {
			.search-result-holder {
				.search-result-clm {
					.result-content {
						width: 100%;
						margin: 15px 0;
					}
					a {
						margin-left: 0;
					}
				}
			}
		}
	}
}
@media screen and (max-width: 1099px) {
	.select-product-cat-wrapper {
		.select-cat-step-wrapper {
			.select-category-graphic {
				width: 40%;
				h1 {
					font-size: 23px;
					line-height: 28px;
				}
			}
		}
	}
}
@media screen and (max-width: 1200px) {
	.select-product-cat-wrapper {
		.select-cat-step-wrapper {
			.product-search-wrapper {
				.list-group {
					width: calc(100% + 61px);
					.list-group-item {
						max-width: 100%;
						padding: 13px;
					}
				}
			}
		}
	}
}
@media screen and (max-width: 950px) {
	form.stat-date-range {
		.panel-heading {
			.form-group {
				display: inline-block;
				vertical-align: top;
				margin: 0;
				&:last-of-type {
					display: block;
					margin-top: 5px;
				}
			}
			.date-inp-wrap {
				input {
					width: 150px;
				}
			}
		}
	}
}
@media screen and (min-width: 992px) {
	.order-address-info {
		>.row {
			display: flex;
		}
	}
}
@media screen and (max-width: 1030px) {
	.transaction-details {
		#vendor_transactions_date_filter {
			width: 100%;
			text-align: center;
			margin-bottom: 15px;
		}
		#vendor_transactions_wrapper {
			>.row {
				text-align: center;
				.col-sm-6 {
					width: 100%;
				}
			}
		}
	}
}
@media (max-width: 767px) {
	.vendor-announcements {
		.msg_arrow_box2 {
			min-height: auto;
		}
		.msg_title_box2 {
			min-height: auto;
		}
		.msg_date_box2 {
			min-height: auto;
		}
	}
}
